<?xml version="1.0" encoding="UTF-8"?>
<!--
########################################################################
# metaf-sum.xsl
#
# copyright (c) metaf2xml 2006-2010
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
########################################################################
-->

<xsl:stylesheet
    xmlns:xsl = "http://www.w3.org/1999/XSL/Transform"
    version = "1.0">

 <!-- this must be passed with "- -stringparam name value" from xsltproc -->
 <xsl:param name="lang"/>
 <xsl:param name="no_msg"/>

 <xsl:variable name="lang_used">
  <xsl:choose>
   <xsl:when test="$lang = 'en' or $lang = 'es' or $lang = 'ru'">
    <xsl:value-of select="$lang"/>
   </xsl:when>
   <xsl:when test="$lang = '' and (/data/options/@lang = 'en' or /data/options/@lang = 'es' or /data/options/@lang = 'ru')">
    <xsl:value-of select="/data/options/@lang"/>
   </xsl:when>
   <xsl:otherwise>de</xsl:otherwise>
  </xsl:choose>
 </xsl:variable>

 <xsl:variable name="trans" select="document('metaf-lang.xsl')//trans/lang[@lang=$lang_used]"/>

 <xsl:variable name="NM2KM" select="1.852"/>
 <xsl:variable name="FT2M" select="0.3048"/>
 <xsl:variable name="SM2M" select="1609.3412196"/> <!-- statute mile! -->
 <xsl:variable name="METER_PER_SEC2KT" select="3.6 div $NM2KM"/>
 <xsl:variable name="INHG2HPA" select="33.86388640341"/>

 <xsl:template match="data">
  <xsl:apply-templates select="reports"/>
 </xsl:template>

 <xsl:template match="reports">
  <xsl:variable name="metaflangversion" select="document('metaf-lang.xsl')//trans/@version"/>
  <xsl:choose>
   <xsl:when test="not(boolean(@version)) or @version != '1.40'">
    <b>
    <xsl:value-of select="concat($trans/hdr[@o='ERROR'], $trans/error[@o='versionsDiffer'], ': XML: ', @version, ' &lt;@&gt; metaf-sum.xsl: 1.40')"/>
    </b>
    <p /><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:when test="'1.40' != $metaflangversion">
    <b>
    <xsl:value-of select="concat($trans/hdr[@o='ERROR'], $trans/error[@o='versionsDiffer'], ': metaf-sum.xsl: 1.40 &lt;@&gt; metaf-lang.xsl: ', $metaflangversion)"/>
    </b>
    <p /><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:if test="boolean(metar)">
     <table border="1" cellpadding="3">
     <xsl:apply-templates select="metar"/>
     </table>
     <xsl:text>&#10;</xsl:text>
     <xsl:if test="boolean(synop)"><br /></xsl:if>
    </xsl:if>
    <xsl:if test="boolean(synop)">
     <table border="1" cellpadding="3">
     <xsl:apply-templates select="synop"/>
     </table>
     <xsl:text>&#10;</xsl:text>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$method = 'html'">
   <xsl:comment> metaf-sum: 1.40 </xsl:comment>
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="version_xsl">
  <xsl:text>1.40</xsl:text>
 </xsl:template>

 <xsl:template name="stationInfo">
  <xsl:param name="station"/>
  <xsl:if test="boolean($station)">
   <xsl:value-of select="concat(' (', $station, ', ', $trans/country[@o=$station/@ctry], ')')"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="metar">
  <xsl:if test="position() mod 15 = 1">
   <xsl:choose>
    <xsl:when test="not($no_msg != '')">
     <xsl:copy-of select="$trans/summaryHeader[@o='metarMsg']/tr"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:copy-of select="$trans/summaryHeader[@o='metar']/tr"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:element name="tr">
   <xsl:attribute name="title">
    <xsl:apply-templates select="obsStationId|callSign"/>
    <xsl:apply-templates select="obsStationId|callSign" mode="stationInfo">
     <xsl:with-param name="type" select="'ICAO'"/>
    </xsl:apply-templates>
   </xsl:attribute>
   <td nowrap="1">
   <xsl:choose>
    <xsl:when test="boolean(isSpeci)"><b>SPECI</b></xsl:when>
    <xsl:otherwise>METAR</xsl:otherwise>
   </xsl:choose>
   <xsl:apply-templates select="reportModifier/modifierType[@v = 'NIL' or @v = 'AUTO' or @v = 'COR' or @v = 'AMD' or @v = 'RTD']"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="obsStationId"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="obsTime"/></td>
   <xsl:text>&#9;</xsl:text>
   <xsl:variable name="gust">
    <xsl:apply-templates select="sfcWind/wind/gustSpeed|remark/peakWind/wind/speed|remark/sfcWind/wind/gustSpeed"/>
   </xsl:variable>
   <xsl:if test="not(boolean(sfcWind))">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$gust"/>
    </td><xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:apply-templates select="sfcWind">
    <xsl:with-param name="gust" select="$gust"/>
   </xsl:apply-templates>
   <xsl:choose>
    <xsl:when test="boolean(CAVOK)">
     <td colspan="3">CAVOK</td><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1" align="right">
     <xsl:apply-templates select="visPrev"/>
     <xsl:apply-templates select="visMin"/>
     </td><xsl:text>&#9;</xsl:text>
     <td nowrap="1"><xsl:apply-templates select="weather"/></td>
     <xsl:text>&#9;</xsl:text>
     <td nowrap="1">
      <xsl:apply-templates select="cloud"/>
      <xsl:apply-templates select="visVert"/>
     </td><xsl:text>&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <td nowrap="1" align="right">
   <xsl:apply-templates select="temperature/air/temp"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
   <xsl:if test="boolean(temperature/relHumid1)">
    <xsl:value-of select="concat(format-number(temperature/relHumid1/@v, '0'), '%')"/>
   </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right"><xsl:apply-templates select="QNH|QFE"/></td>
   <xsl:text>&#9;</xsl:text>
   <xsl:variable name="rows">
    <xsl:choose>
     <xsl:when test="boolean(trend)">
      <xsl:apply-templates select="trend" mode="count"/>
     </xsl:when>
     <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <xsl:apply-templates select="remark/notRecognised"/>
   </xsl:element>
   <xsl:if test="not($no_msg != '')">
    <xsl:text>&#9;</xsl:text>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="style">font-family: monospace; font-size: 90%;</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <xsl:choose>
     <xsl:when test="boolean(ERROR)">
      <xsl:value-of select="substring-before(ERROR/@s, '&lt;')"/>
      <b>
      <xsl:value-of select="substring-after(ERROR/@s, '&gt; ')"/>
      </b>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="@s"/>
     </xsl:otherwise>
    </xsl:choose>
    </xsl:element>
   </xsl:if>
   </xsl:element>
   <xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="trend"/>
 </xsl:template>

 <xsl:template match="obsStationId|callSign">
  <xsl:value-of select="id/@v"/>
 </xsl:template>

 <xsl:template match="obsStationId|callSign" mode="stationInfo">
  <xsl:param name="type"/>
  <xsl:choose>
   <xsl:when test="name() = 'callSign'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@callsign=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'ICAO'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@icao=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'AAXX'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@wmo=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'BBXX'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@ship=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="obsTime">
  <xsl:apply-templates select="timeAt"/>
 </xsl:template>

 <xsl:template match="visPrev">
  <xsl:call-template name="visibility">
   <xsl:with-param name="rnd_m" select="50"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
  </xsl:call-template>
 </xsl:template>

 <xsl:template match="visVert">
  <xsl:if test="not(boolean(invalidFormat|notAvailable))">
   <xsl:value-of select="concat('VV', format-number(distance/@v, '000'))"/>
  </xsl:if>
 </xsl:template>

 <xsl:template name="visibility">
  <xsl:param name="rnd_m"/>
  <xsl:param name="unitThreshold"/>
  <xsl:if test="not(boolean(invalidFormat|notAvailable))">
   <xsl:choose>
    <xsl:when test="distance/@q = 'isLess'">&lt;</xsl:when>
    <xsl:when test="distance/@q = 'isGreater'">&gt;</xsl:when>
    <xsl:when test="distance/@q = 'isEqualGreater'">&gt;=</xsl:when>
    <xsl:otherwise></xsl:otherwise>
   </xsl:choose>
   <xsl:variable name="amountMeter">
    <xsl:choose>
     <xsl:when test="distance/@u = 'M'">
      <xsl:value-of select="distance/@v"/>
     </xsl:when>
     <xsl:when test="distance/@u = 'KM'">
      <xsl:value-of select="distance/@v * 1000"/>
     </xsl:when>
     <xsl:when test="distance/@u = 'SM'">
      <xsl:value-of select="distance/@v * $SM2M"/>
     </xsl:when>
     <xsl:when test="distance/@u = 'FT'">
      <xsl:value-of select="distance/@v * $FT2M"/>
     </xsl:when>
      <xsl:when test="distance/@u = 'NM'">
       <xsl:value-of select="distance/@v * $NM2KM * 1000"/>
      </xsl:when>
    </xsl:choose>
   </xsl:variable>
   <xsl:choose>
    <xsl:when test="$amountMeter &gt;= $unitThreshold">
     <xsl:value-of select="concat(format-number($amountMeter div 1000, '0.#'), $trans/units[@o='KM'])"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="concat(format-number($amountMeter div $rnd_m, '#0') * $rnd_m, $trans/units[@o='M'])"/>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:if test="boolean(compassDir)">
    <xsl:value-of select="concat(' ', compassDir/@v)"/>
   </xsl:if>
  </xsl:if>
 </xsl:template>

 <xsl:template match="sfcWind">
  <xsl:param name="gust"/>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="gust" select="$gust"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="wind">
  <xsl:param name="gust"/>
  <xsl:choose>
   <xsl:when test="boolean(invalidFormat|notAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$gust"/>
    </td><xsl:text>&#9;</xsl:text>
   </xsl:when>
   <xsl:when test="boolean(isCalm)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="concat($trans/t[@o='calmWind'], $gust)"/></td>
    <xsl:text>&#9;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="dir">
     <xsl:choose>
      <xsl:when test="boolean(dirNotAvailable)">
      </xsl:when>
      <xsl:when test="boolean(dirVariable)">
       <xsl:text>VRB</xsl:text>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="$trans/compassDir16/arr[1+format-number(current()/dir/@v div 45 * 2, '0')]"/>
       <!--xsl:value-of select="concat(dir/@v, '°')"/-->
       <xsl:if test="boolean(windVarLeft)">
        <xsl:value-of select="concat(' (', $trans/compassDir16/arr[1+format-number(current()/windVarLeft/@v div 45 * 2, '0')], '-', $trans/compassDir16/arr[1+format-number(current()/windVarRight/@v div 45 * 2, '0')], ')')"/>
       </xsl:if>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:choose>
     <xsl:when test="dir/@v = '0' and speed/@v = '0'">
      <td colspan="2" nowrap="1">
      <xsl:value-of select="concat($trans/t[@o='calmWind'], $gust)"/>
      </td>
      <xsl:text>&#9;</xsl:text>
     </xsl:when>
     <xsl:when test="boolean(speedNotAvailable)">
      <td><xsl:value-of select="$dir"/></td>
      <xsl:text>&#9;</xsl:text>
      <td></td>
     </xsl:when>
     <xsl:otherwise>
      <td nowrap="1"><xsl:value-of select="$dir"/></td>
      <xsl:text>&#9;</xsl:text>
      <td nowrap="1" align="right">
      <xsl:call-template name="speed2kt">
       <xsl:with-param name="speed" select="speed"/>
      </xsl:call-template>
      <xsl:value-of select="$gust"/>
      </td>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:text>&#9;</xsl:text>
 </xsl:template>

 <xsl:template match="gustSpeed|speed">
  <xsl:if test="position() = 1"> (^</xsl:if>
  <xsl:if test="position() != 1">, ^</xsl:if>
  <xsl:choose>
   <xsl:when test="name() = 'gustSpeed'">
    <xsl:call-template name="speed2kt">
     <xsl:with-param name="speed" select="."/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="name(../..) = 'highestGust'">
    <xsl:call-template name="speed2kt">
     <xsl:with-param name="speed" select="."/>
    </xsl:call-template>
    <xsl:apply-templates select="../../period|../../timeBeforeObs|../../timeBeforeObsBegin|../../timeBeforeObsEnd|../../timeBeforeObsSince"/>
   </xsl:when>
   <xsl:when test="name(../..) = 'peakWind'">
    <xsl:call-template name="speed2kt">
     <xsl:with-param name="speed" select="."/>
    </xsl:call-template>
    <xsl:if test="boolean(../../timeAt)">
     <xsl:text>/</xsl:text>
     <xsl:if test="boolean(../../timeAt/day)">
      <xsl:value-of select="concat(format-number(../../timeAt/day/@v, '0'), '.')"/>
     </xsl:if>
     <xsl:if test="boolean(../../timeAt/hour)">
      <xsl:value-of select="../../timeAt/hour/@v"/>
     </xsl:if>
     <xsl:if test="boolean(../../timeAt/hour|../../timeAt/minute)">:</xsl:if>
     <xsl:if test="boolean(../../timeAt/minute)">
      <xsl:value-of select="../../timeAt/minute/@v"/>
     </xsl:if>
    </xsl:if>
   </xsl:when>
  </xsl:choose>
  <xsl:if test="position() = last()">)</xsl:if>
 </xsl:template>

 <xsl:template match="timeBeforeObs|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
  <xsl:if test="position() = 1"><xsl:value-of select="'/'"/></xsl:if>
  <xsl:if test="position() != 1"><xsl:text>,</xsl:text></xsl:if>
  <xsl:choose>
   <xsl:when test="boolean(hoursUnknown)">?</xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="printHoursFromTill">
     <xsl:with-param name="hoursStr">
      <xsl:choose>
       <xsl:when test="name() = 'timeBeforeObsBegin'">*|h</xsl:when>
       <xsl:when test="name() = 'timeBeforeObsEnd'">+|h</xsl:when>
       <xsl:when test="name() = 'timeBeforeObsSince'">|h</xsl:when>
       <xsl:otherwise>@|h</xsl:otherwise>
      </xsl:choose>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printHoursFromTill">
  <xsl:param name="hoursStr"/>
  <xsl:value-of select="substring-before($hoursStr, '|')"/>
  <xsl:if test="hoursFrom/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:value-of select="hoursFrom/@v"/>
  <xsl:if test="boolean(hoursTill)">
   <xsl:if test="boolean(hoursFrom)">-</xsl:if>
   <xsl:if test="hoursTill/@q = 'isLess'">&lt;</xsl:if>
   <xsl:value-of select="hoursTill/@v"/>
  </xsl:if>
  <xsl:value-of select="substring-after($hoursStr, '|')"/>
 </xsl:template>

 <xsl:template match="period">
  <xsl:value-of select="concat('/', @v)"/>
  <xsl:if test="@u = 'SEC'">s</xsl:if>
  <xsl:if test="@u = 'MIN'">m</xsl:if>
  <xsl:if test="@u = 'H'">h</xsl:if>
 </xsl:template>

 <xsl:template name="speed2kt">
  <xsl:param name="speed"/>
  <xsl:if test="$speed/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:variable name="speedkt">
   <xsl:choose>
    <xsl:when test="$speed/@u = 'KT'">
     <xsl:value-of select="$speed/@v"/>
    </xsl:when>
    <xsl:when test="$speed/@u = 'KMH'">
     <xsl:value-of select="$speed/@v div $NM2KM"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$speed/@v * $METER_PER_SEC2KT"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:value-of select="format-number($speedkt, '0.#')"/>
 </xsl:template>

 <xsl:template match="weather">
  <xsl:if test="position() != 1"><xsl:value-of select="' '"/></xsl:if>
  <xsl:apply-templates select="phenomDescr"/>
  <xsl:if test="boolean(inVicinity)">VC</xsl:if>
  <xsl:if test="boolean(NSW)">NSW</xsl:if>
  <xsl:if test="boolean(tornado)">TORNADO</xsl:if>
  <xsl:apply-templates select="descriptor"/>
  <xsl:apply-templates select="phenomSpec"/>
 </xsl:template>

 <xsl:template match="phenomDescr">
  <xsl:if test="@v = 'isHeavy'">+</xsl:if>
  <xsl:if test="@v = 'isLight'">-</xsl:if>
 </xsl:template>

 <xsl:template match="descriptor">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="phenomSpec">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="cloud">
  <xsl:if test="position() != 1"><xsl:value-of select="' '"/></xsl:if>
  <xsl:choose>
   <xsl:when test="boolean(invalidFormat|notAvailable)">
   </xsl:when>
   <xsl:when test="boolean(noClouds)">
    <xsl:value-of select="noClouds/@v"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="cloud">
     <xsl:value-of select="cloudCover/@v"/>
     <xsl:choose>
      <xsl:when test="boolean(baseBelowStation)">///</xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="cloudBaseVal"/>
      </xsl:otherwise>
     </xsl:choose>
     <xsl:if test="boolean(cloudType)">
      <xsl:value-of select="cloudType/@v"/>
     </xsl:if>
     <xsl:if test="boolean(cloudTypeNotAvailable)">
      <xsl:text>///</xsl:text>
     </xsl:if>
    </xsl:variable>
    <xsl:choose>
     <xsl:when test="boolean(isCeiling)">
      <b><xsl:value-of select="$cloud"/></b>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$cloud"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="cloudBaseVal">
  <xsl:if test="cloudBase/@q = 'isLess'">
   <xsl:text>&lt;</xsl:text>
  </xsl:if>
  <xsl:if test="cloudBase/@q = 'isGreater'">
   <xsl:text>&gt;</xsl:text>
  </xsl:if>
  <xsl:if test="cloudBase/@q = 'isEqualGreater'">
   <xsl:text>&gt;=</xsl:text>
  </xsl:if>
  <xsl:if test="cloudBase/@u = 'FT'">
   <xsl:value-of select="format-number(cloudBase/@v div 100, '000')"/>
  </xsl:if>
  <xsl:if test="cloudBase/@u = 'M'">
   <xsl:value-of select="format-number(cloudBase/@v div 100 div $FT2M, '00') * 10"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="temp">
  <xsl:call-template name="printTemp">
   <xsl:with-param name="temp" select=".."/>
  </xsl:call-template>
 </xsl:template>

 <xsl:template match="notRecognised|obsStationType|warning">
  <xsl:if test="position() &gt; 1"><xsl:text> </xsl:text></xsl:if>
  <xsl:value-of select="@s"/>
 </xsl:template>

 <xsl:template name="printTemp">
  <xsl:param name="temp"/>
  <xsl:if test="not(boolean($temp/notAvailable))">
   <xsl:choose>
    <xsl:when test="$temp/temp/@u = 'C'">
     <xsl:value-of select="$temp/temp/@v"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="format-number(($temp/temp/@v - 32) div 1.8, '0.#')"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
 </xsl:template>

 <xsl:template match="stationPressure|QNH|SLP|QFE">
  <xsl:if test="boolean(inHg|hPa|mmHg)">
   <xsl:if test="position() != 1"><xsl:text> </xsl:text></xsl:if>
   <xsl:choose>
    <xsl:when test="name() = 'stationPressure'">SP</xsl:when>
    <xsl:otherwise><xsl:value-of select="name()"/></xsl:otherwise>
   </xsl:choose>
   <xsl:choose>
    <xsl:when test="boolean(hPa)">
     <xsl:value-of select="hPa/@v"/>
    </xsl:when>
    <xsl:when test="boolean(mmHg)">
     <xsl:value-of select="format-number(mmHg/@v div ($FT2M div 12 * 1000) * $INHG2HPA, '0')"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="format-number(inHg/@v * $INHG2HPA, '0')"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:if test="boolean(../remark/QNH|../remark/SLP|../remark/QFE)">
   <xsl:text> (</xsl:text>
   <xsl:apply-templates select="../remark/QNH|../remark/SLP|../remark/QFE"/>
   <xsl:text>)</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="remark">
  <xsl:variable name="rmk">
   <xsl:value-of select="name(child::*[last()])"/>
  </xsl:variable>
  <xsl:choose>
   <xsl:when test="$rmk = 'cloud'">
    <xsl:apply-templates select="cloud">
     <xsl:with-param name="s_list" select="cloud/@s"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$rmk = 'visRwy'">
    <xsl:apply-templates select="visRwy">
     <xsl:with-param name="unitThreshold" select="1000"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="child::*[last()]"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="visMin">
  <xsl:text>, </xsl:text>
  <xsl:call-template name="visibility">
   <xsl:with-param name="rnd_m" select="10"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
  </xsl:call-template>
  <xsl:text>&#9;</xsl:text>
 </xsl:template>

 <xsl:template match="trend" mode="count">
  <xsl:if test="position() = last()">
   <xsl:choose>
    <xsl:when test="trendType/@v = 'NOSIG'">1</xsl:when>
    <xsl:otherwise><xsl:value-of select="last() + 1"/></xsl:otherwise>
   </xsl:choose>
  </xsl:if>
 </xsl:template>

 <xsl:template match="trend">
  <xsl:if test="trendType/@v != 'NOSIG'">
   <tr>
   <td colspan="2"/><xsl:text>&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:value-of select="trendType/@v"/>
   <xsl:if test="boolean(probability)">
    <xsl:value-of select="concat(' PROB ', probability/@v, '%')"/>
   </xsl:if>
   <xsl:apply-templates select="timeAt|timeFrom|timeTill">
    <xsl:with-param name="pre" select="' '"/>
    <xsl:with-param name="need_type" select="1"/>
   </xsl:apply-templates>
   </td><xsl:text>&#9;</xsl:text>
   <xsl:if test="not(boolean(sfcWind))">
    <td colspan="2"/><xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:apply-templates select="sfcWind"/>
   <xsl:choose>
    <xsl:when test="boolean(CAVOK)">
     <td colspan="3">CAVOK</td><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1" align="right">
     <xsl:apply-templates select="visPrev"/>
     <xsl:apply-templates select="visMin"/>
     </td><xsl:text>&#9;</xsl:text>
     <td nowrap="1"><xsl:apply-templates select="weather"/></td>
     <xsl:text>&#9;</xsl:text>
     <td nowrap="1">
      <xsl:apply-templates select="cloud"/>
      <xsl:apply-templates select="visVert"/>
     </td><xsl:text>&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <td colspan="3"/>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="timeAt|timeFrom|timeTill">
  <xsl:param name="pre"/>
  <xsl:param name="need_type"/>
  <xsl:if test="position() = 1"><xsl:value-of select="$pre"/></xsl:if>
  <xsl:if test="position() = 2"><xsl:value-of select="' '"/></xsl:if>
  <xsl:if test="$need_type">
   <xsl:choose>
    <xsl:when test="name() = 'timeAt'">AT </xsl:when>
    <xsl:when test="name() = 'timeFrom'">FM </xsl:when>
    <xsl:otherwise>TL </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:if test="boolean(day)">
   <xsl:value-of select="concat(day/@v, '., ')"/>
  </xsl:if>
  <xsl:value-of select="concat(hour/@v, ':')"/>
  <xsl:choose>
   <xsl:when test="boolean(minute)">
    <xsl:value-of select="minute/@v"/>
   </xsl:when>
   <xsl:otherwise>00</xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="synop">
  <xsl:if test="position() mod 15 = 1">
   <xsl:choose>
    <xsl:when test="not($no_msg != '')">
     <xsl:copy-of select="$trans/summaryHeader[@o='synopMsg']/tr"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:copy-of select="$trans/summaryHeader[@o='synop']/tr"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:element name="tr">
   <xsl:attribute name="title">
    <xsl:apply-templates select="obsStationId|callSign"/>
    <xsl:apply-templates select="obsStationId|callSign" mode="stationInfo">
     <xsl:with-param name="type" select="obsStationType/stationType/@v"/>
    </xsl:apply-templates>
   </xsl:attribute>
   <td nowrap="1">
   <xsl:text>SYNOP</xsl:text>
   <xsl:apply-templates select="reportModifier/modifierType[@v = 'NIL' or @v = 'AUTO' or @v = 'COR' or @v = 'AMD' or @v = 'RTD']"/>
   </td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="obsStationType"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="obsTime"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="obsStationId|callSign"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
   <xsl:apply-templates select="visPrev"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1">
   <xsl:if test="boolean(totalCloudCover/skyObscured)">?/8</xsl:if>
   <xsl:if test="boolean(totalCloudCover/oktas)">
    <xsl:value-of select="concat(totalCloudCover/oktas/@v, '/8')"/>
   </xsl:if>
   <xsl:if test="boolean(baseLowestCloud/from)">
    <xsl:text> </xsl:text>
    <xsl:if test="baseLowestCloud/from/@q = 'isEqualGreater'">
     <xsl:text>&gt;=</xsl:text>
    </xsl:if>
    <xsl:value-of select="baseLowestCloud/from/@v"/>
    <xsl:if test="boolean(baseLowestCloud/to)">
     <xsl:value-of select="concat('..', baseLowestCloud/to/@v)"/>
    </xsl:if>
    <xsl:value-of select="$trans/units[@o=current()/baseLowestCloud/from/@u]"/>
   </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <xsl:variable name="gust">
    <xsl:apply-templates select="section3/highestGust/wind/speed|section5/highestGust/wind/speed|section5/peakWind/wind/speed"/>
   </xsl:variable>
   <xsl:if test="not(boolean(sfcWind))">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$gust"/>
    </td><xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:apply-templates select="sfcWind">
    <xsl:with-param name="gust" select="$gust"/>
   </xsl:apply-templates>
   <td nowrap="1" align="right">
   <xsl:apply-templates select="temperature/air/temp"/>
   <xsl:apply-templates select="section3/tempMaxPeriod|section3/tempMinPeriod|section3/tempMaxDaytime|section3/tempMinNighttime"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
   <xsl:if test="boolean(temperature/relHumid1)">
    <xsl:value-of select="concat(format-number(temperature/relHumid1/@v, '0'), '%')"/>
   </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
    <xsl:apply-templates select="stationPressure|SLP"/>
    <xsl:if test="boolean(gpSurface/geopotential)">
     <xsl:value-of select="concat(gpSurface/surface/@v, ': ', gpSurface/geopotential/@v)"/>
    </xsl:if>
    <xsl:if test="boolean(pressureChange/pressureChangeVal)">
     <xsl:variable name="sign">
      <xsl:if test="pressureChange/pressureChangeVal/@v &gt; 0">+</xsl:if>
     </xsl:variable>
     <xsl:value-of select="concat(' (', $sign, pressureChange/pressureChangeVal/@v)"/>
     <xsl:apply-templates select="pressureChange/period"/>
     <xsl:text>)</xsl:text>
    </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <xsl:choose>
    <xsl:when test="boolean(precipHourly/precipAmount|precipHourly/traces|section3/precipHourly/precipAmount|precipHourly/traces)">
     <xsl:apply-templates select="precipHourly/precipAmount|precipHourly/traces|section3/precipHourly/precipAmount|section3/precipHourly/traces"/>
    </xsl:when>
    <xsl:otherwise>
     <td colspan="3"/><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:choose>
    <xsl:when test="boolean(weatherSynop/weatherPresent|weatherSynop/weatherPresentSimple|section3/weatherSynopAdd/weatherPresent|section3/weatherSynopAmpl/weatherPresent)">
     <td nowrap="1">
     <xsl:apply-templates select="weatherSynop/weatherPresent|weatherSynop/weatherPresentSimple|section3/weatherSynopAdd/weatherPresent|section3/weatherSynopAmpl/weatherPresent"/>
     </td><xsl:text>&#9;</xsl:text>
    </xsl:when>
    <xsl:when test="wxInd/wxIndVal/@v = 2 or wxInd/wxIndVal/@v = 5">
     <td>-</td><xsl:text>&#9;</xsl:text>
    </xsl:when>
    <xsl:when test="wxInd/wxIndVal/@v = 3 or wxInd/wxIndVal/@v = 6">
     <td>?</td><xsl:text>&#9;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
     <td/><xsl:text>&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:choose>
    <xsl:when test="boolean(cloudTypes/skyObscured)">
     <td colspan="3">?/8</td>
     <xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:when>
    <xsl:when test="boolean(cloudTypes) and not(boolean(cloudTypes/notAvailable) or (boolean(cloudTypes/cloudTypeLowNA) and boolean(cloudTypes/cloudTypeMiddleNA) and boolean(cloudTypes/cloudTypeHighNA)))">
     <td nowrap="1">
     <xsl:choose>
      <xsl:when test="boolean(cloudTypes/oktasLow)">
       <xsl:value-of select="concat(cloudTypes/oktasLow/@v, '/8 ')"/>
      </xsl:when>
      <xsl:when test="cloudTypes/cloudTypeLow/@v = 0">0/8</xsl:when>
     </xsl:choose>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 1">CU fr</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 2">CU con</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 3">CB cal</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 4">SC cugen</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 5">SC</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 6">ST neb</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 7">ST/CU fra</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 8">CU,SC</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeLow/@v = 9">CB cap</xsl:if>
     </td><xsl:text>&#9;</xsl:text>
     <td nowrap="1">
     <xsl:choose>
      <xsl:when test="boolean(cloudTypes/oktasMiddle)">
       <xsl:value-of select="concat(cloudTypes/oktasMiddle/@v, '/8 ')"/>
      </xsl:when>
      <xsl:when test="cloudTypes/cloudTypeMiddle/@v = 0">0/8</xsl:when>
     </xsl:choose>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 1">AS tr</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 2">AS op/NS</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 3">AC tr</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 4">AC tr/len</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 5">AC tr/op</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 6">AC cugen/cbgen</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 7">AC tr/op,AC,AS/NS</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 8">AC cas/flo</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeMiddle/@v = 9">AC</xsl:if>
     </td><xsl:text>&#9;</xsl:text>
     <td nowrap="1">
     <xsl:choose>
      <xsl:when test="cloudTypes/cloudTypeHigh/@v = 0">0/8</xsl:when>
     </xsl:choose>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 1">CI fib/unc</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 2">CI spi/cas/flo</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 3">CI spi cbgen</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 4">CI unc/fib</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 5">CI,CS</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 6">CI,CS</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 7">CS</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 8">CS</xsl:if>
     <xsl:if test="cloudTypes/cloudTypeHigh/@v = 9">CC</xsl:if>
     </td><xsl:text>&#9;</xsl:text>
    </xsl:when>
    <xsl:when test="boolean(cloudTypes/oktas)">
     <td nowrap="1" colspan="3">
     <xsl:value-of select="concat(cloudTypes/oktas/@v, '/8 ')"/>
     </td><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
     <td colspan="3"/><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:choose>
    <xsl:when test="boolean(section3/cloudInfo)">
     <xsl:apply-templates select="section3/cloudInfo"/>
    </xsl:when>
    <xsl:otherwise>
     <td colspan="3"/><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <td nowrap="1">
   <xsl:apply-templates select="warning[@warningType='notProcessed']"/>
   </td>
   <xsl:if test="not($no_msg != '')">
    <xsl:text>&#9;</xsl:text>
    <td nowrap="1" style="font-family: monospace; font-size: 90%;">
    <xsl:choose>
     <xsl:when test="boolean(ERROR)">
      <xsl:value-of select="substring-before(ERROR/@s, '&lt;')"/>
      <b>
      <xsl:value-of select="substring-after(ERROR/@s, '&gt; ')"/>
      </b>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="@s"/>
     </xsl:otherwise>
    </xsl:choose>
    </td>
   </xsl:if>
  </xsl:element>
  <xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="modifierType">
  <xsl:value-of select="concat(' ', @v)"/>
 </xsl:template>

 <xsl:template match="weatherPresent|weatherPresentSimple">
  <xsl:if test="position() &gt; 1"><xsl:text>, </xsl:text></xsl:if>
  <xsl:choose>
   <xsl:when test="name() = 'weatherPresentSimple'">
    <xsl:value-of select="document('metaf-lang.xsl')//trans/weatherPresentSimpleSum/arr[current()/@v + 1]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="document('metaf-lang.xsl')//trans/weatherPresentSum/arr[current()/@v + 1]"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="cloudInfo">
  <xsl:if test="position() &lt; 4">
   <xsl:variable name="cols">
    <xsl:choose>
     <xsl:when test="position() = last() and position() = 1">3</xsl:when>
     <xsl:when test="position() = last() and position() = 2">2</xsl:when>
     <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="colspan"><xsl:value-of select="$cols"/></xsl:attribute>
    <xsl:if test="boolean(cloudOktas/oktas)">
     <xsl:value-of select="concat(cloudOktas/oktas/@v, '/8 ')"/>
    </xsl:if>
    <xsl:if test="boolean(cloudType)">
     <xsl:value-of select="concat(cloudType/@v, ' ')"/>
    </xsl:if>
    <xsl:if test="boolean(cloudBase)">
     <xsl:if test="cloudBase/@q = 'isLess'">
      <xsl:text>&lt;</xsl:text>
     </xsl:if>
     <xsl:if test="cloudBase/@q = 'isGreater'">
      <xsl:text>&gt;</xsl:text>
     </xsl:if>
     <xsl:if test="cloudBase/@q = 'isEqualGreater'">
      <xsl:text>&gt;=</xsl:text>
     </xsl:if>
     <xsl:value-of select="concat(cloudBase/@v, $trans/units[@o=current()/cloudBase/@u])"/>
    </xsl:if>
    <xsl:if test="boolean(cloudBaseFrom)">
     <xsl:value-of select="concat(cloudBaseFrom/@v, '..', cloudBaseTo/@v, $trans/units[@o=current()/cloudBase/@u])"/>
    </xsl:if>
   </xsl:element>
   <xsl:text>&#9;</xsl:text>
   <xsl:if test="position() = last() and position() = 1">
    <xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:if test="position() = last() and position() = 2">
    <xsl:text>&#9;</xsl:text>
   </xsl:if>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tempMaxPeriod|tempMinPeriod|tempMaxDaytime|tempMinNighttime">
  <xsl:choose>
   <xsl:when test="name() = 'tempMaxPeriod' or name() = 'tempMaxDaytime'">
    <xsl:text> (^</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text> (v</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="temp" select="."/>
  </xsl:call-template>
  <xsl:apply-templates select="period"/>
  <xsl:text>)</xsl:text>
 </xsl:template>

 <xsl:template match="precipAmount|traces">
  <xsl:if test="position() &lt; 4">
   <xsl:variable name="cols">
    <xsl:choose>
     <xsl:when test="position() = last() and position() = 1">3</xsl:when>
     <xsl:when test="position() = last() and position() = 2">2</xsl:when>
     <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="colspan"><xsl:value-of select="$cols"/></xsl:attribute>
    <xsl:if test="name() = 'traces'">
     <xsl:value-of select="$trans/t[@o='traces']"/>
    </xsl:if>
    <xsl:if test="name() = 'precipAmount'">
     <xsl:value-of select="concat(@v, $trans/units[@o=current()/@u])"/>
    </xsl:if>
    <xsl:apply-templates select="../period"/>
   </xsl:element>
   <xsl:text>&#9;</xsl:text>
   <xsl:if test="position() = last() and position() = 1">
    <xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:if test="position() = last() and position() = 2">
    <xsl:text>&#9;</xsl:text>
   </xsl:if>
  </xsl:if>
 </xsl:template>

</xsl:stylesheet>
