<?xml version="1.0" encoding="UTF-8"?>
<!--
########################################################################
# metaf.xsl 1.40
#   templates to transform XML to HTML or text
#
# copyright (c) metaf2xml 2006-2010
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
########################################################################
-->

<xsl:stylesheet
    xmlns:xsl = "http://www.w3.org/1999/XSL/Transform"
    version = "1.0">

 <!-- set parameter with option "- -stringparam name value" of xsltproc -->
 <xsl:param name="lang"/>

 <xsl:variable name="lang_used">
  <xsl:choose>
   <xsl:when test="$lang = 'en' or $lang = 'es' or $lang = 'ru'">
    <xsl:value-of select="$lang"/>
   </xsl:when>
   <xsl:when test="$lang = '' and (/data/options/@lang = 'en' or /data/options/@lang = 'es' or /data/options/@lang = 'ru')">
    <xsl:value-of select="/data/options/@lang"/>
   </xsl:when>
   <xsl:otherwise>de</xsl:otherwise>
  </xsl:choose>
 </xsl:variable>

 <xsl:variable name="trans" select="document('metaf-lang.xsl')//trans/lang[@lang=$lang_used]"/>

 <xsl:variable name="NM2KM" select="1.852"/>
 <xsl:variable name="FT2M" select="0.3048"/>
 <xsl:variable name="SM2M" select="1609.34"/><!-- U.S. and int. statute mile -->
 <xsl:variable name="INHG2HPA" select="33.86388640341"/>

 <xsl:template match="data">
  <xsl:apply-templates select="reports"/>
 </xsl:template>

 <xsl:template match="reports">
  <xsl:variable name="metaflangversion" select="document('metaf-lang.xsl')//trans/@version"/>
  <xsl:choose>
   <xsl:when test="not(boolean(@version)) or @version != '1.40'">
    <b>
    <xsl:value-of select="concat($trans/hdr[@o='ERROR'], $trans/error[@o='versionsDiffer'], ': XML: ', @version, ' &lt;@&gt; metaf.xsl: 1.40')"/>
    </b>
    <p /><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:when test="'1.40' != $metaflangversion">
    <b>
    <xsl:value-of select="concat($trans/hdr[@o='ERROR'], $trans/error[@o='versionsDiffer'], ': metaf.xsl: 1.40 &lt;@&gt; metaf-lang.xsl: ', $metaflangversion)"/>
    </b>
    <p /><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="taf|metar|synop"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$method = 'html'">
   <xsl:comment> metaf.xsl: 1.40 </xsl:comment>
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="version_xsl">
  <xsl:text>1.40</xsl:text>
 </xsl:template>

 <xsl:template match="synop">
  <table border="1" cellpadding="2">
  <xsl:call-template name="table_head"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td><b>SYNOP</b></td>
  </xsl:if>
  <th nowrap="1" colspan="3">
  <xsl:value-of select="$trans/hdr[@o='synop']"/>
  <xsl:choose>
   <xsl:when test="boolean(obsTime/timeAt/hour) and (obsTime/timeAt/hour/@v = '00' or obsTime/timeAt/hour/@v = '06' or obsTime/timeAt/hour/@v = '12' or obsTime/timeAt/hour/@v = '18')">
    <xsl:value-of select="$trans/t[@o='synopMainHour']"/>
   </xsl:when>
   <xsl:when test="boolean(obsTime/timeAt/hour) and (obsTime/timeAt/hour/@v = '03' or obsTime/timeAt/hour/@v = '09' or obsTime/timeAt/hour/@v = '15' or obsTime/timeAt/hour/@v = '21')">
    <xsl:value-of select="$trans/t[@o='synopIntermHour']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='synopNonstandardHour']"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:apply-templates select="reportModifier"/>
  <xsl:if test="$method != 'html'">
   <xsl:value-of select="concat('&#10;', $trans/hdr[@o='synop_ul'])"/>
  </xsl:if>
  </th>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(obsStationType)">
   <xsl:call-template name="section">
    <xsl:with-param name="section_nr" select="0"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:apply-templates select="obsStationType|callSign|obsTime|windIndicator|stationPosition|obsStationId|precipInd|wxInd|baseLowestCloud|visPrev|visibilityAtLoc|totalCloudCover|sfcWind|temperature|stationPressure|SLP|gpSurface|pressureChange|precipHourly|weatherSynop|cloudTypes|exactObsTime|section2|section3|section4|section5">
   <xsl:with-param name="type" select="obsStationType/stationType/@v"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="ERROR"/>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position() != last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template match="taf">
  <table border="1" cellpadding="2">
  <xsl:call-template name="table_head"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td><b>TAF</b></td>
  </xsl:if>
  <th nowrap="1" colspan="3">
  <xsl:choose>
   <xsl:when test="not(boolean(fcstPeriod/timeFrom))">
    <xsl:value-of select="$trans/hdr[@o='taf']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="hours">
     <xsl:choose>
      <xsl:when test="boolean(fcstPeriod/timeFrom/day) and boolean(fcstPeriod/timeTill/day) and fcstPeriod/timeFrom/day/@v &lt;= fcstPeriod/timeTill/day/@v">
       <xsl:value-of select="fcstPeriod/timeTill/hour/@v - fcstPeriod/timeFrom/hour/@v + 24 * (fcstPeriod/timeTill/day/@v - fcstPeriod/timeFrom/day/@v)"/>
      </xsl:when>
      <!-- TODO: how to detect if dayFrom+1 > dayTill across end of month? -->
      <xsl:when test="boolean(fcstPeriod/timeFrom/day) and boolean(fcstPeriod/timeTill/day) and fcstPeriod/timeFrom/hour/@v &lt; fcstPeriod/timeTill/hour/@v">
       <xsl:value-of select="fcstPeriod/timeTill/hour/@v - fcstPeriod/timeFrom/hour/@v + 24"/>
      </xsl:when>
      <xsl:when test="fcstPeriod/timeFrom/hour/@v &lt; fcstPeriod/timeTill/hour/@v">
       <xsl:value-of select="fcstPeriod/timeTill/hour/@v - fcstPeriod/timeFrom/hour/@v"/>
      </xsl:when>
      <xsl:when test="boolean(fcstPeriod/timeFrom/day) and boolean(fcstPeriod/timeTill/day) and fcstPeriod/timeFrom/day/@v != fcstPeriod/timeTill/day/@v">
       <xsl:value-of select="fcstPeriod/timeTill/hour/@v - fcstPeriod/timeFrom/hour/@v + 24"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="fcstPeriod/timeTill/hour/@v - fcstPeriod/timeFrom/hour/@v + 24"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="concat(substring-before($trans/hdr[@o='taf_hour'], '|'), $hours, substring-after($trans/hdr[@o='taf_hour'], '|'))"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:apply-templates select="reportModifier"/>
  <xsl:if test="$method != 'html'">
   <xsl:value-of select="concat('&#10;', $trans/hdr[@o='taf_ul'])"/>
  </xsl:if>
  </th>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="obsStationId|issueTime|fcstPeriod|fcstCancelled|fcstNotAvbl|sfcWind|CAVOK|visPrev|weather[1]|cloud[1]|visVert|turbulence|icing|windShearLvl|QNH|obscuration|tempAt|tempMaxAt|tempMinAt|correctedAt|amendedAt|limMetwatch|autoMetwatch|amendment|trend[1]|tafRemark[1]">
   <xsl:with-param name="type" select="'ICAO'"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="ERROR"/>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position() != last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template match="metar">
  <table border="1" cellpadding="2">
  <xsl:call-template name="table_head"/>
  <tr>
  <xsl:choose>
   <xsl:when test="boolean(isSpeci)">
    <xsl:if test="$method = 'html'">
     <td><b>SPECI</b></td>
    </xsl:if>
    <th nowrap="1" colspan="3">
    <xsl:value-of select="$trans/hdr[@o='speci']"/>
    <xsl:apply-templates select="reportModifier"/>
    <xsl:if test="$method != 'html'">
     <xsl:value-of select="concat('&#10;', $trans/hdr[@o='speci_ul'])"/>
    </xsl:if>
    </th>
   </xsl:when>
   <xsl:otherwise>
    <xsl:if test="$method = 'html'">
     <td><b>METAR</b></td>
    </xsl:if>
    <th nowrap="1" colspan="3">
    <xsl:value-of select="$trans/hdr[@o='metar']"/>
    <xsl:apply-templates select="reportModifier"/>
    <xsl:if test="$method != 'html'">
     <xsl:value-of select="concat('&#10;', $trans/hdr[@o='metar_ul'])"/>
    </xsl:if>
    </th>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="obsStationId|obsTime|sfcWind|CAVOK|visPrev|visRwy|RVRNO|weather[1]|cloud[1]|visVert|temperature|QNH|QFE|waterTemp|seaCondition|windShear|rwyState|somePressure|recentWeather[1]|QFF|colourCode|cloudMaxCover|NEFO_PLAYA|RH|windAtLoc|rwyWind|trend[1]|remark[1]">
   <xsl:with-param name="type" select="'ICAO'"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="ERROR"/>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position() != last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template name="table_head">
  <tr>
  <td colspan="4" style="font-family: monospace; font-size: 90%;">
  <xsl:value-of select="concat('msg: ', @s)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="warning"/>
 </xsl:template>

 <xsl:template name="src_string">
  <xsl:param name="rows"/>
  <xsl:param name="s"/>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:if test="$rows != ''">
     <xsl:attribute name="rowspan">
      <xsl:value-of select="$rows"/>
     </xsl:attribute>
    </xsl:if>
    <b>
    <xsl:choose>
     <xsl:when test="$s != ''"><xsl:value-of select="$s"/></xsl:when>
     <xsl:otherwise><xsl:value-of select="@s"/></xsl:otherwise>
    </xsl:choose>
    </b>
   </xsl:element>
  </xsl:if>
 </xsl:template>

 <xsl:template name="hdr_string">
  <xsl:param name="hdr_name"/>
  <xsl:param name="rows"/>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:if test="$rows != ''">
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   </xsl:if>
   <xsl:choose>
    <xsl:when test="$hdr_name != ''">
     <xsl:value-of select="$trans/hdr[@o=$hdr_name]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/hdr[@o=name(current())]"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:element>
 </xsl:template>

 <xsl:template name="unitConverter">
  <xsl:param name="val"/>
  <xsl:param name="unit"/>
  <xsl:param name="factor"/>
  <xsl:param name="format"/>
  <xsl:param name="range"/>
  <xsl:if test="$val/@q = 'isEqualGreater'">&gt;=</xsl:if>
  <xsl:if test="$val/@q = 'isLess'">&lt;</xsl:if>
  <xsl:if test="$val/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:choose>
   <xsl:when test="$unit = '' or $val/@u = $unit">
    <xsl:value-of select="$val/@v"/>
    <xsl:if test="boolean($val/@rp)">
     <xsl:choose>
      <xsl:when test="$range != ''">
       <xsl:value-of select="concat(' .. &lt;', $val/@v + $val/@rp)"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="concat(' (.. &lt;', $val/@v + $val/@rp, ')')"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:if>
    <xsl:value-of select="$trans/units[@o=$val/@u]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="conv_rate">
     <xsl:choose>
      <xsl:when test="$val/@u = 'IN' and $unit = 'MM'">
       <xsl:value-of select="$FT2M div 12 * 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MM' and $unit = 'IN'">
       <xsl:value-of select="12 div $FT2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'IN' and $unit = 'CM'">
       <xsl:value-of select="$FT2M div 12 * 100"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'CM' and $unit = 'IN'">
       <xsl:value-of select="12 div $FT2M div 100"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'FT' and $unit = 'M'">
       <xsl:value-of select="$FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'M' and $unit = 'FT'">
       <xsl:value-of select="1 div $FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'FT' and $unit = 'KM'">
       <xsl:value-of select="$FT2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KM' and $unit = 'FT'">
       <xsl:value-of select="1000 div $FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'NM' and $unit = 'M'">
       <xsl:value-of select="$NM2KM * 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'M' and $unit = 'NM'">
       <xsl:value-of select="1 div 1000 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'NM' and $unit = 'KM'">
       <xsl:value-of select="$NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KM' and $unit = 'NM'">
       <xsl:value-of select="1 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'FT' and $unit = 'SM'">
       <xsl:value-of select="$FT2M div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'SM' and $unit = 'FT'">
       <xsl:value-of select="$SM2M div $FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'SM' and $unit = 'M'">
       <xsl:value-of select="$SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'M' and $unit = 'SM'">
       <xsl:value-of select="1 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'SM' and $unit = 'KM'">
       <xsl:value-of select="$SM2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KM' and $unit = 'SM'">
       <xsl:value-of select="1000 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KT' and $unit = 'KMH'">
       <xsl:value-of select="$NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KMH' and $unit = 'KT'">
       <xsl:value-of select="1 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KMH' and $unit = 'MPH'">
       <xsl:value-of select="1000 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPH' and $unit = 'KMH'">
       <xsl:value-of select="$SM2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KMH' and $unit = 'MPS'">
       <xsl:value-of select="1 div 3.6"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPS' and $unit = 'KMH'">
       <xsl:value-of select="3.6"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPS' and $unit = 'KT'">
       <xsl:value-of select="3.6 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KT' and $unit = 'MPS'">
       <xsl:value-of select="$NM2KM div 3.6"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPS' and $unit = 'MPH'">
       <xsl:value-of select="3600 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPH' and $unit = 'MPS'">
       <xsl:value-of select="$SM2M div 3600"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KT' and $unit = 'MPH'">
       <xsl:value-of select="$NM2KM * 1000 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPH' and $unit = 'KT'">
       <xsl:value-of select="$SM2M div $NM2KM div 1000"/>
      </xsl:when>
     </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="format-number($val/@v div $factor * $conv_rate, $format)"/>
    <xsl:if test="$factor = 10 and not($val/@v = '0')">
     <xsl:text>0</xsl:text>
    </xsl:if>
    <xsl:value-of select="$trans/units[@o=$unit]"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="reportModifier">
  <xsl:text>&#9;&#9;(</xsl:text>
  <xsl:value-of select="$trans/reportModifierType[@o=current()/modifierType/@v]"/>
  <xsl:if test="modifierType/@v = 'P'">
   <xsl:value-of select="concat($trans/t[@o='segment'],' ', segment/@v)"/>
    <xsl:if test="boolean(isLastSegment)">
     <xsl:value-of select="concat(' (', $trans/t[@o='last'],')')"/>
    </xsl:if>
  </xsl:if>
  <xsl:if test="boolean(over24hLate)">
   <xsl:value-of select="$trans/t[@o='over24hLate']"/>
  </xsl:if>
  <xsl:if test="boolean(sequenceLost)">
   <xsl:value-of select="$trans/t[@o='sequenceLost']"/>
  </xsl:if>
  <xsl:if test="boolean(bulletinSeq)">
   <xsl:value-of select="concat($trans/t[@o='bulletinSeq'], bulletinSeq/@v)"/>
  </xsl:if>
  <xsl:text>)</xsl:text>
 </xsl:template>

 <xsl:template match="precipInd">
  <xsl:call-template name="section">
   <xsl:with-param name="section_nr" select="1"/>
  </xsl:call-template>
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'precipIndicator'"/>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/precipIndicator[@o=current()/precipIndVal/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="wxInd">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'wxIndicator'"/>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/wxIndicator[@o=current()/wxIndVal/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="baseLowestCloud">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:if test="boolean(to)">2</xsl:if>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="hdr_string"/>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="from"/>
     <xsl:with-param name="unit" select="'M'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="from"/>
     <xsl:with-param name="unit" select="'FT'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(to)">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'to'"/>
   </xsl:call-template>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="to"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="to"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="stationPosition">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:apply-templates select="notAvailable"/>
   </xsl:when>
   <xsl:when test="lat/@v &lt; 0">
    <xsl:value-of select="format-number(-lat/@v, '0.0° S')"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="format-number(lat/@v, '0.0° N')"/>
    <!--xsl:value-of select="concat(format-number(lat/@v - lat/@v mod 1, '00'), format-number((lat/@v mod 1) * 60, '00N'))"/-->
   </xsl:otherwise>
  </xsl:choose>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)"/>
   <xsl:when test="lon/@v &lt; 0">
    <xsl:value-of select="format-number(-lon/@v, ' 0.0° W')"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="format-number(lon/@v, ' 0.0° E')"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="totalCloudCover">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:call-template name="cloudOktas"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="gpSurface">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="boolean(geopotential)">
    <xsl:value-of select="concat(substring-before($trans/hdr[@o='gpSurface'], '|'), surface/@v, substring-after($trans/hdr[@o='gpSurface'], '|'))"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/hdr[@o='gpSurfaceNA']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat)">
    <xsl:apply-templates select="notAvailable|invalidFormat"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(geopotential/@v, $trans/units[@o='gpm'])"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="weatherSynop|weatherSynopAdd|weatherSynopAmplPast|weatherSynopAmpl|weatherSynopPast">
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="name() = 'weatherSynop'">
     <xsl:choose>
      <xsl:when test="boolean(weatherPast1|weatherPast1Simple) and boolean(weatherPast2NotAvailable)">3</xsl:when>
      <xsl:when test="boolean(weatherPast2|weatherPast2Simple) and boolean(weatherPast1NotAvailable)">3</xsl:when>
      <xsl:when test="boolean(weatherPast1) and boolean(weatherPast2) and weatherPast1/@v != weatherPast2/@v">3</xsl:when>
      <xsl:when test="boolean(weatherPast1Simple) and boolean(weatherPast2Simple) and weatherPast1Simple/@v != weatherPast2Simple/@v">3</xsl:when>
      <xsl:otherwise>2</xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:when test="boolean(weatherSynopFG/visVertFrom)">2</xsl:when>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="name() = 'weatherSynop'">
    <xsl:value-of select="$trans/hdr[@o='weather']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="substring-before($trans/hdr[@o=name(current())], '|')"/>
    <xsl:apply-templates select="period|timeBeforeObs|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
    <xsl:value-of select="substring-after($trans/hdr[@o=name(current())], '|')"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="boolean(weatherSynopFG)">
   <xsl:value-of select="$trans/hdr[@o='weatherSynopFG']"/>
  </xsl:if>
  </td>
  <xsl:choose>
   <xsl:when test="boolean(weatherPresentNotAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(weatherPresent)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/weatherSynop[@o=current()/weatherPresent/@v]"/>
    <xsl:apply-templates select="phenomVariation|location|phenomDescr">
     <xsl:with-param name="pre" select="', '"/>
    </xsl:apply-templates>
    </td>
   </xsl:when>
   <xsl:when test="boolean(weatherPresentSimple)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/weatherSynopSimple[@o=current()/weatherPresentSimple/@v]"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(weatherPresent1)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/weatherSynop1[@o=current()/weatherPresent1/@v]"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(weatherSynopFG)">
    <xsl:if test="boolean(weatherSynopFG/visVert)">
     <xsl:call-template name="visibility">
      <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
      <xsl:with-param name="visVal" select="weatherSynopFG/visVert"/>
     </xsl:call-template>
    </xsl:if>
    <xsl:if test="boolean(weatherSynopFG/visVertFrom)">
     <xsl:call-template name="visibility">
      <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
      <xsl:with-param name="visVal" select="weatherSynopFG/visVertFrom"/>
     </xsl:call-template>
    </xsl:if>
   </xsl:when>
   <xsl:when test="boolean(weatherSynopPrecip)">
    <td nowrap="1" colspan="2">
    <xsl:for-each select="weatherSynopPrecip">
     <xsl:call-template name="printWeather"/>
    </xsl:for-each>
    <xsl:value-of select="$trans/hdr[@o='weatherSynopPrecip']"/>
    <xsl:if test="boolean(weatherSynopPrecip/rateOfFall)">
     <xsl:call-template name="unitConverter">
      <xsl:with-param name="val" select="weatherSynopPrecip/rateOfFall"/>
     </xsl:call-template>
    </xsl:if>
    <xsl:if test="boolean(weatherSynopPrecip/rateOfFallFrom)">
     <xsl:value-of select="concat(weatherSynopPrecip/rateOfFallFrom/@v, ' - ', weatherSynopPrecip/rateOfFallTo/@v)"/>
     <xsl:value-of select="$trans/units[@o=current()/weatherSynopPrecip/rateOfFallFrom/@u]"/>
    </xsl:if>
    </td>
   </xsl:when>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="name() = 'weatherSynop'">
   <tr>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:if test="$rows &gt; 2">
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows - 1"/></xsl:attribute>
    </xsl:if>
    <xsl:apply-templates select="period">
     <xsl:with-param name="pre" select="' '"/>
     <xsl:with-param name="header" select="$trans/hdr[@o='weatherPast']"/>
    </xsl:apply-templates>
   </xsl:element>
   <td nowrap="1" colspan="2">
   <xsl:choose>
    <xsl:when test="boolean(weatherPast1NotAvailable)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="boolean(weatherPast1Simple)">
     <xsl:value-of select="$trans/weatherSynopPastSimple[@o=current()/weatherPast1Simple/@v]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/weatherSynopPast[@o=current()/weatherPast1/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(weatherSynopFG/visVertTo)">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'to'"/>
   </xsl:call-template>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="weatherSynopFG/visVertTo"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="$rows = 3">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1" colspan="2">
   <xsl:choose>
    <xsl:when test="boolean(weatherPast2NotAvailable)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="boolean(weatherPast2Simple)">
     <xsl:value-of select="$trans/weatherSynopPastSimple[@o=current()/weatherPast2Simple/@v]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/weatherSynopPast[@o=current()/weatherPast2/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="period|measurePeriod|radiationPeriod|sunshinePeriod">
  <xsl:param name="header"/>
  <xsl:param name="pre"/>
  <xsl:if test="$header != ''">
   <xsl:value-of select="substring-before($header, '|')"/>
  </xsl:if>
  <xsl:value-of select="$pre"/>
  <xsl:choose>
   <xsl:when test="@v = '1d' or @v = 'n' or @v = '6to6' or @v = '0618p'">
    <xsl:value-of select="$trans/period[@o=current()/@v]"/>
   </xsl:when>
   <xsl:when test="name() = 'measurePeriod'">
    <xsl:value-of select="concat($trans/t[@o='during'], @v, $trans/units[@o=current()/@u])"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat($trans/t[@o='since'], @v, $trans/units[@o=current()/@u])"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$header != ''">
   <xsl:value-of select="substring-after($header, '|')"/>
  </xsl:if>
 </xsl:template>

 <xsl:template name="section">
  <xsl:param name="s"/>
  <xsl:param name="section_nr"/>
  <xsl:if test="$method = 'html'">
   <tr>
   <xsl:choose>
    <xsl:when test="$s != ''">
     <td nowrap="1"><b><xsl:value-of select="$s"/></b></td>
    </xsl:when>
    <xsl:otherwise>
     <td></td>
    </xsl:otherwise>
   </xsl:choose>
   <td nowrap="1" colspan="3"><b>
   <xsl:value-of select="concat($trans/t[@o='section'], ' ', $section_nr, ':')"/>
   </b></td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="windIndicator">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/units[@o=current()/windUnit/@v]"/>
    <xsl:if test="boolean(isEstimated)">
     <xsl:value-of select="concat(', ', $trans/t[@o='estimated'])"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsStationId|callSign">
  <xsl:param name="type"/>
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="id/@v"/>
  <xsl:if test="boolean(region)">
   <xsl:value-of select="concat(' (', $trans/wmoRegion[@o=current()/region/@v], ')')"/>
  </xsl:if>
  <xsl:choose>
   <xsl:when test="name() = 'callSign'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@callsign=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'ICAO'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@icao=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'AAXX'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@wmo=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'BBXX'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@ship=current()/id/@v]"/>
    </xsl:call-template>
   </xsl:when>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="stationInfo">
  <xsl:param name="station"/>
  <xsl:if test="boolean($station)">
   <xsl:value-of select="concat(' (', $station, ', ', $trans/country[@o=$station/@ctry], ')')"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="fcstPeriod|obsTime|issueTime|exactObsTime|nextFcst|amdAt|correctedAt|amendedAt">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="invalidFormat|timeAt|timeBy|timeFrom|timeTill"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="fcstAutoObs|limMetwatch|autoMetwatch|windShift">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/hdr[@o=name(current())]"/>
  <xsl:apply-templates select="timeAt|timeFrom|timeTill">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(FROPA)">
   <xsl:value-of select="concat(' ', $trans/t[@o='FROPA'])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visPrev">
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(NDV) and boolean(../visMin)">3</xsl:when>
    <xsl:when test="boolean(NDV|../visMin)">2</xsl:when>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
   <xsl:with-param name="s">
    <xsl:if test="boolean(../visMin)">
     <xsl:value-of select="concat(@s, ' ', ../visMin/@s)"/>
    </xsl:if>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(NDV)">
   <tr><td nowrap="1" colspan="2">
   <xsl:value-of select="concat('&#9;&#9;&#9;', $trans/t[@o='NDV'])"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(../visMin)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
    <xsl:with-param name="visVal" select="../visMin"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="visVert">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
   <xsl:with-param name="visVal" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visRwy">
  <xsl:variable name="hdr" select="$trans/hdr[@o='visRwy']"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(RVRVariations) and boolean(visTrend)">3</xsl:when>
    <xsl:when test="boolean(RVRVariations|visTrend)">2</xsl:when>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:if test="$rows != ''">
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   </xsl:if>
   <xsl:value-of select="concat(substring-before($hdr, '|'), rwyDesig/@v, substring-after($hdr, '|'))"/>
  </xsl:element>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='rwyVisNotAvailable']"/>
   <xsl:with-param name="fromto">
    <xsl:if test="boolean(RVRVariations)">
     <xsl:value-of select="concat($trans/t[@o='variable-from'], ' ')"/>
    </xsl:if>
   </xsl:with-param>
   <xsl:with-param name="visVal" select="RVR"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(RVRVariations)">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='rwyVisNotAvailable']"/>
    <xsl:with-param name="fromto" select="concat($trans/t[@o='variable-to'], ' ')"/>
    <xsl:with-param name="visVal" select="RVRVariations"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(visTrend)">
   <tr>
   <td nowrap="1" colspan="2">
    <xsl:value-of select="concat($trans/hdr[@o='visTrend'], $trans/visTrend[@o=current()/visTrend/@v])"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(RVRVariations|visTrend)"><xsl:text>&#10;</xsl:text></xsl:if>
 </xsl:template>

 <xsl:template name="visibility">
  <xsl:param name="notavail"/>
  <xsl:param name="fromto"/>
  <xsl:param name="visVal"/>
  <xsl:choose>
   <xsl:when test="boolean($visVal/invalidFormat)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="$visVal/invalidFormat"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean($visVal/notAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$notavail"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="compassDir">
     <xsl:apply-templates select="$visVal/compassDir">
      <xsl:with-param name="pre" select="concat(substring-before($trans/t[@o='compassDirTo'], '|'),substring-before($trans/t[@o='compassDirDescr'], '|'))"/>
      <xsl:with-param name="post" select="concat(substring-after($trans/t[@o='compassDirDescr'], '|'),substring-after($trans/t[@o='compassDirTo'], '|'))"/>
     </xsl:apply-templates>
    </xsl:variable>
    <td nowrap="1">
    <xsl:value-of select="$fromto"/>
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="$visVal/distance"/>
    </xsl:call-template>
    <xsl:value-of select="$compassDir"/>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="($visVal/distance/@u = 'M' and $visVal/distance/@v &lt; 2000) or ($visVal/distance/@u = 'KM' and $visVal/distance/@v &lt; 2)">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'FT'"/>
       <xsl:with-param name="factor" select="10"/>
       <xsl:with-param name="format" select="'0'"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:when test="$visVal/distance/@u = 'KM' or $visVal/distance/@u = 'M'">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'SM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:when test="($visVal/distance/@u = 'FT' and $visVal/distance/@v &lt; 6000) or (($visVal/distance/@u = 'SM' or $visVal/distance/@u = 'NM') and $visVal/distance/@v &lt; 2)">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'M'"/>
       <xsl:with-param name="factor" select="10"/>
       <xsl:with-param name="format" select="'0'"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'KM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$compassDir"/>
    </td>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="compassDir|cloudDir">
  <xsl:param name="pre"/>
  <xsl:param name="post"/>
  <xsl:variable name="v" select="@v"/>
  <xsl:value-of select="$pre"/>
  <xsl:if test="@q = 'isGrid'">
   <xsl:value-of select="$trans/t[@o='isGrid']"/>
  </xsl:if>
  <xsl:value-of select="concat($trans/compassDir[@o=$v], $post)"/>
 </xsl:template>

 <xsl:template match="timeAt|timeBy|timeFrom|timeSince|timeTill">
  <xsl:param name="pre"/>
  <xsl:variable name="minute">
   <xsl:choose>
    <xsl:when test="boolean(minute)">
     <xsl:value-of select="minute/@v"/>
    </xsl:when>
    <xsl:otherwise>0</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="position() = 1"><xsl:value-of select="$pre"/></xsl:if>
  <xsl:if test="position() = 2"><xsl:value-of select="' '"/></xsl:if>
  <xsl:choose>
   <xsl:when test="boolean(day)">
    <xsl:choose>
     <xsl:when test="name() = 'timeAt'">
      <xsl:value-of select="$trans/t[@o='onDate']"/>
     </xsl:when>
     <xsl:when test="name() = 'timeBy'">
      <xsl:value-of select="$trans/t[@o='byDate']"/>
     </xsl:when>
     <xsl:when test="name() = 'timeSince'">
      <xsl:value-of select="$trans/t[@o='sinceDate']"/>
     </xsl:when>
     <xsl:when test="name() = 'timeTill'">
      <xsl:value-of select="$trans/t[@o='tillDate']"/>
     </xsl:when>
     <xsl:when test="position() = 1 and last() = 2">
      <xsl:value-of select="$trans/t[@o='fromTillDate']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$trans/t[@o='fromDate']"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="concat(format-number(day/@v, '0'), '., ')"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:choose>
     <xsl:when test="name() = 'timeFrom' and position() = 1 and last() = 2">
      <xsl:value-of select="$trans/t[@o='timeFromTill']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$trans/t[@o=name(current())]"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:choose>
   <xsl:when test="boolean(hour)">
    <xsl:value-of select="concat(format-number(hour/@v, '00:'), format-number($minute, '00 UTC'))"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(format-number($minute, '0'), $trans/t[@o='afterHour'])"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="position() = 2 and not(boolean(day)) and boolean(../timeFrom/hour) and boolean(hour) and ../timeFrom/hour/@v &gt;= hour/@v">
   <xsl:variable name="minuteFrom">
    <xsl:choose>
     <xsl:when test="boolean(../timeFrom/minute)">
      <xsl:value-of select="../timeFrom/minute/@v"/>
     </xsl:when>
     <xsl:otherwise>0</xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:if test="$minuteFrom &gt;= $minute">
    <xsl:value-of select="$trans/t[@o='nextDay']"/>
   </xsl:if>
  </xsl:if>
 </xsl:template>

 <xsl:template match="peakWind">
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr">
    <xsl:value-of select="substring-before($trans/hdr[@o='peakWind'], '|')"/>
    <xsl:apply-templates select="timeAt">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
    <xsl:value-of select="substring-after($trans/hdr[@o='peakWind'], '|')"/>
   </xsl:with-param>
   <xsl:with-param name="s" select="@s"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="rwyWind|thrWind">
  <xsl:variable name="hdr" select="$trans/hdr[@o=name(current())]"/>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr" select="concat(substring-before($hdr, '|'), rwyDesig/@v, substring-after($hdr, '|'))"/>
   <xsl:with-param name="s"   select="@s"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="sfcWind">
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='sfcWind']"/>
   <xsl:with-param name="s"   select="@s"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="windAtLoc">
  <xsl:variable name="loc">
   <xsl:choose>
    <xsl:when test="windLocation/@v = 'RS'">
     <xsl:value-of select="$trans/t[@o='RS']"/>
    </xsl:when>
    <xsl:when test="windLocation/@v = 'TWR'">
     <xsl:value-of select="$trans/t[@o='TWR']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="windLocation/@v"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr" select="concat(substring-before($trans/hdr[@o='windAtLoc'], '|'), $loc, substring-after($trans/hdr[@o='windAtLoc'], '|'))"/>
   <xsl:with-param name="s"   select="@s"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="wind">
  <xsl:param name="hdr"/>
  <xsl:param name="s"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(gustSpeed) and boolean(windVarLeft)">3</xsl:when>
    <xsl:when test="boolean(gustSpeed|windVarLeft)">2</xsl:when>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$s != ''">
   <xsl:call-template name="src_string">
    <xsl:with-param name="rows" select="$rows"/>
    <xsl:with-param name="s" select="$s"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:if test="$rows != ''">
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   </xsl:if>
   <xsl:value-of select="$hdr"/>
  </xsl:element>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="notAvailable|invalidFormat"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(isCalm)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='calmWind']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="dir">
     <xsl:choose>
      <xsl:when test="boolean(dirNotAvailable)">
       <xsl:value-of select="$trans/t[@o='dirNotAvailable']"/>
      </xsl:when>
      <xsl:when test="boolean(dirVariable)">
       <xsl:value-of select="$trans/t[@o='dirVariable']"/>
      </xsl:when>
      <xsl:when test="boolean(dirVarAllUnk)">
       <xsl:value-of select="$trans/t[@o='dirVarAllUnk']"/>
      </xsl:when>
      <xsl:when test="boolean(dir)">
       <xsl:value-of select="concat($trans/t[@o='wind-from'], ' ')"/>
       <xsl:if test="dir/@q = 'isGrid'">
        <xsl:value-of select="$trans/t[@o='isGrid']"/>
       </xsl:if>
       <xsl:value-of select="$trans/compassDir16/arr[1+format-number(current()/dir/@v div 45 * 2, '0')]"/>
       <xsl:value-of select="concat(' (', dir/@v, '°')"/>
       <xsl:choose>
        <xsl:when test="boolean(dir/@rp) and boolean(dir/@rn)">
         <xsl:value-of select="concat(' (+', dir/@rp, '°/-', dir/@rn, '°)')"/>
        </xsl:when>
        <xsl:when test="boolean(dir/@rp)">
         <xsl:value-of select="concat(' (+', dir/@rp, '°)')"/>
        </xsl:when>
        <xsl:when test="boolean(dir/@rn)">
         <xsl:value-of select="concat(' (-', dir/@rn, '°)')"/>
        </xsl:when>
       </xsl:choose>
       <xsl:text>)</xsl:text>
      </xsl:when>
     </xsl:choose>
    </xsl:variable>
    <xsl:choose>
     <xsl:when test="boolean(speedNotAvailable)">
      <td nowrap="1" colspan="2">
      <xsl:value-of select="$dir"/>
      <xsl:if test="$dir != ''">
       <xsl:if test="not(boolean(dirNotAvailable))">,</xsl:if>
       <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:value-of select="$trans/t[@o='speedNotAvailable']"/>
      </td>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="printSpeed">
       <xsl:with-param name="dir" select="$dir"/>
       <xsl:with-param name="speed" select="speed"/>
       <xsl:with-param name="delim" select="'&#9;&#9;'"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(gustSpeed)">
   <tr>
   <xsl:call-template name="printSpeed">
    <xsl:with-param name="dir" select="$trans/t[@o='wind-gusts']"/>
    <xsl:with-param name="speed" select="gustSpeed"/>
    <xsl:with-param name="delim" select="'&#9;&#9;&#9;'"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(windVarLeft)">
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="concat($trans/t[@o='variable'], ' ')"/>
   <xsl:value-of select="concat($trans/t[@o='variable-from'],' ')"/>
   <xsl:value-of select="concat($trans/compassDir16/arr[1+format-number(current()/windVarLeft/@v div 45 * 2, '0')], ' ')"/>
   <xsl:value-of select="concat($trans/t[@o='variable-to'], ' ')"/>
   <xsl:value-of select="concat($trans/compassDir16/arr[1+format-number(current()/windVarRight/@v div 45 * 2, '0')], ' ')"/>
   <xsl:value-of select="concat('(', windVarLeft/@v, '°--', windVarRight/@v, '°)')"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="printSpeed">
  <xsl:param name="dir"/>
  <xsl:param name="speed"/>
  <xsl:param name="delim"/>
  <xsl:param name="greater"/>
  <td nowrap="1">
  <xsl:if test="$dir != ''">
   <xsl:value-of select="concat($dir, ' ', $trans/t[@o='wind-at'], ' ')"/>
  </xsl:if>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'KMH'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
  </xsl:call-template>
  </td>
  <xsl:value-of select="$delim"/>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'KT'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
  </xsl:call-template>
  <xsl:text> = </xsl:text>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'MPH'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
  </xsl:call-template>
  <xsl:text> = </xsl:text>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'MPS'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
  </xsl:call-template>
  </td>
 </xsl:template>

 <!-- combine all weather nodes into one set and process them in one go -->
 <xsl:template match="weather">
  <xsl:apply-templates select="../weather" mode="go">
   <xsl:with-param name="s">
    <xsl:apply-templates select="../weather" mode="concat_s"/>
   </xsl:with-param>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="recentWeather">
  <xsl:apply-templates select="../recentWeather" mode="go">
   <xsl:with-param name="s">
    <xsl:apply-templates select="../recentWeather" mode="concat_s"/>
   </xsl:with-param>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="weather|recentWeather|cloud" mode="concat_s">
  <xsl:value-of select="concat(' ', @s)"/>
 </xsl:template>

 <xsl:template match="weather|recentWeather" mode="go">
  <xsl:param name="s"/>
  <xsl:variable name="rows">
   <xsl:if test="last() != 1"><xsl:value-of select="last()"/></xsl:if>
  </xsl:variable>
  <xsl:choose>
   <xsl:when test="position() = 1">
    <tr>
    <xsl:call-template name="src_string">
     <xsl:with-param name="rows" select="$rows"/>
     <xsl:with-param name="s" select="substring($s, 2)"/>
    </xsl:call-template>
    <xsl:call-template name="hdr_string">
     <xsl:with-param name="rows" select="$rows"/>
    </xsl:call-template>
    <td nowrap="1" colspan="2">
    <xsl:call-template name="printWeather"/>
    </td>
    </tr>
   </xsl:when>
   <xsl:otherwise>
    <tr><td nowrap="1" colspan="2">
    <xsl:if test="$method = 'text'">, </xsl:if>
    <xsl:call-template name="printWeather"/>
    </td></tr>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="position() = last()">
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="printWeather">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat)">
    <xsl:apply-templates select="notAvailable|invalidFormat"/>
   </xsl:when>
   <xsl:when test="boolean(NSW)">
    <xsl:value-of select="$trans/weather[@o='NSW']"/>
   </xsl:when>
   <xsl:when test="boolean(tornado)">
    <xsl:value-of select="$trans/weather[@o='tornado']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="w_all">
     <xsl:apply-templates select="descriptor"/>
     <xsl:apply-templates select="phenomSpec"/>
    </xsl:variable>
    <xsl:variable name="phenomDescr">
     <xsl:apply-templates select="phenomDescr">
      <xsl:with-param name="post" select="' '"/>
     </xsl:apply-templates>
    </xsl:variable>
    <xsl:variable name="w_all_trans">
     <xsl:choose>
      <xsl:when test="$trans/weather[@o=$w_all] != ''">
       <xsl:variable name="w_trans" select="$trans/weather[@o=$w_all]"/>
       <xsl:value-of select="concat(substring-before($w_trans, '|'), $phenomDescr, substring-after($w_trans, '|'))"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="@s"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$w_all_trans"/>
    <xsl:if test="boolean(inVicinity)">
     <xsl:value-of select="concat(' ', $trans/locationSpec[@o='inVicinity'])"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="descriptor|phenomSpec">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="cloud" mode="ceiling">
  <xsl:if test="boolean(isCeiling) and cloudBase/@u = 'FT'">
   <xsl:value-of select="cloudBase/@v"/>
  </xsl:if>
 </xsl:template>

 <!-- combine all cloud nodes into one set and process them in one go -->
 <xsl:template match="cloud">
  <xsl:apply-templates select="../cloud" mode="go"/>
 </xsl:template>

 <xsl:template match="cloud" mode="go">
  <xsl:choose>
   <xsl:when test="position() = 1">
    <xsl:variable name="ceiling">
     <xsl:apply-templates select="../cloud" mode="ceiling"/>
    </xsl:variable>
    <xsl:variable name="s">
     <xsl:apply-templates select="../cloud" mode="concat_s"/>
    </xsl:variable>
    <xsl:variable name="rows">
     <xsl:if test="last() != 1"><xsl:value-of select="last()"/></xsl:if>
    </xsl:variable>
    <tr>
    <xsl:call-template name="src_string">
     <xsl:with-param name="rows">
      <xsl:choose>
       <xsl:when test="$ceiling != ''"><xsl:value-of select="last() + 1"/></xsl:when>
       <xsl:otherwise><xsl:value-of select="$rows"/></xsl:otherwise>
      </xsl:choose>
     </xsl:with-param>
     <xsl:with-param name="s" select="substring($s, 2)"/>
    </xsl:call-template>
    <xsl:choose>
     <xsl:when test="$ceiling != ''">
      <xsl:call-template name="hdr_string">
       <xsl:with-param name="hdr_name" select="'ceiling'"/>
      </xsl:call-template>
      <td nowrap="1">
      <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' ', $ceiling, $trans/units[@o='FT'])"/>
      </td>
      <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
      <td nowrap="1">
      <xsl:value-of select="concat(format-number($ceiling div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
      </td>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="hdr_string">
       <xsl:with-param name="rows" select="$rows"/>
      </xsl:call-template>
      <xsl:call-template name="printCloud">
       <xsl:with-param name="at_abv" select="'cloud-at'"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    </tr><xsl:text>&#10;</xsl:text>
    <xsl:if test="$ceiling != ''">
     <tr>
     <xsl:call-template name="hdr_string">
      <xsl:with-param name="rows" select="$rows"/>
     </xsl:call-template>
     <xsl:call-template name="printCloud">
      <xsl:with-param name="at_abv" select="'cloud-at'"/>
     </xsl:call-template>
     </tr><xsl:text>&#10;</xsl:text>
    </xsl:if>
   </xsl:when>
   <xsl:otherwise>
    <tr>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <xsl:call-template name="printCloud">
     <xsl:with-param name="at_abv" select="'cloud-at'"/>
    </xsl:call-template>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printCloud">
  <xsl:param name="at_abv"/>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="notAvailable|invalidFormat"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(noClouds)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/cloudCover[@o=current()/noClouds/@v]"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:if test="not(boolean(cloudBase))">
      <xsl:attribute name="colspan">2</xsl:attribute>
     </xsl:if>
     <xsl:if test="boolean(cloudCover)">
      <xsl:value-of select="$trans/cloudCover[@o=current()/cloudCover/@v]"/>
     </xsl:if>
     <xsl:if test="boolean(cloudCoverNotAvailable)">
      <xsl:value-of select="$trans/phenomenon[@o='CLDS']"/>
     </xsl:if>
     <xsl:if test="boolean(cloudBase)">
      <xsl:value-of select="concat(' ', $trans/t[@o=$at_abv], ' ')"/>
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="cloudBase"/>
       <xsl:with-param name="unit" select="'FT'"/>
       <xsl:with-param name="factor" select="10"/>
       <xsl:with-param name="format" select="'0'"/>
      </xsl:call-template>
     </xsl:if>
     <xsl:if test="boolean(baseBelowStation)">
      <xsl:value-of select="concat(', ', $trans/t[@o='baseBelowStation'])"/>
     </xsl:if>
     <xsl:if test="boolean(cloudType)">
      <br />
      <xsl:value-of select="concat(' (', $trans/cloudType[@o=current()/cloudType/@v], ')')"/>
     </xsl:if>
     <xsl:if test="boolean(cloudTypeNotAvailable)">
      <xsl:value-of select="concat(' ', $trans/t[@o='cloudTypeNotAvailable'])"/>
     </xsl:if>
    </xsl:element>
    <xsl:if test="boolean(cloudBase)">
     <xsl:text>&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:call-template name="unitConverter">
      <xsl:with-param name="val" select="cloudBase"/>
      <xsl:with-param name="unit" select="'M'"/>
      <xsl:with-param name="factor" select="10"/>
      <xsl:with-param name="format" select="'0'"/>
     </xsl:call-template>
     </td>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="temperature">
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(air) and boolean(dewpoint) and boolean(relHumid1)">3</xsl:when>
    <xsl:when test="boolean(air) and boolean(dewpoint|relHumid1)">2</xsl:when>
    <xsl:when test="boolean(dewpoint) and boolean(relHumid1)">2</xsl:when>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="boolean(air)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-temp']"/>
    <xsl:with-param name="rows" select="$rows"/>
    <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="temp" select="air"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(dewpoint)">
   <tr>
   <xsl:choose>
    <xsl:when test="boolean(air)">
     <xsl:call-template name="printTemp">
      <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-dew']"/>
      <xsl:with-param name="temp" select="dewpoint"/>
     </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
     <xsl:call-template name="printTemp">
      <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-dew']"/>
      <xsl:with-param name="rows" select="$rows"/>
      <xsl:with-param name="s" select="@s"/>
      <xsl:with-param name="temp" select="dewpoint"/>
     </xsl:call-template>
    </xsl:otherwise>
   </xsl:choose>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(relHumid1)">
   <tr>
    <xsl:if test="not(boolean(air)) and not(boolean(dewpoint))">
     <xsl:call-template name="src_string"/>
    </xsl:if>
    <xsl:call-template name="hdr_string">
     <xsl:with-param name="hdr_name" select="'relHumid'"/>
    </xsl:call-template>
    <td nowrap="1" colspan="2">
    <xsl:value-of select="format-number(relHumid1/@v, '0')"/>
    <xsl:text>%</xsl:text>
    </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tempHourly">
  <xsl:if test="boolean(air/temp)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='tempHourly-temp']"/>
    <xsl:with-param name="rows">
     <xsl:if test="boolean(air/temp) and boolean(dewpoint/temp)">2</xsl:if>
    </xsl:with-param>
    <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="temp" select="air"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(dewpoint/temp)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='tempHourly-dew']"/>
    <xsl:with-param name="temp" select="dewpoint"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tempAt|SST|OAT|tempMaxFQ|tempCity">
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o=name(current())]"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="tempMaxAt|tempMinAt|tempMaxPeriod|tempMinPeriod|tempMaxDaytime|tempMinNighttime|tempCityMax|tempCityMin|waterTemp|tempMinGround|tempGround">
  <xsl:variable name="period">
   <xsl:choose>
    <xsl:when test="boolean(period)">
     <xsl:apply-templates select="period">
      <xsl:with-param name="pre" select="' '"/>
     </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="boolean(periodNotAvailable) and boolean(temp)">
     <xsl:value-of select="$trans/t[@o='periodNotAvailable']"/>
    </xsl:when>
    <xsl:otherwise></xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:variable name="hdr" select="$trans/hdr[@o=name(current())]"/>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="concat(substring-before($hdr, '|'), $period, substring-after($hdr, '|'))"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="temp24h">
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr">
    <xsl:apply-templates select="tempMaxPeriod/period">
     <xsl:with-param name="pre" select="' '"/>
     <xsl:with-param name="header" select="$trans/hdr[@o='tempMaxPeriod']"/>
    </xsl:apply-templates>
   </xsl:with-param>
   <xsl:with-param name="rows">
    <xsl:if test="boolean(tempMinPeriod/temp)">2</xsl:if>
   </xsl:with-param>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="tempMaxPeriod"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(tempMinPeriod/temp)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr">
     <xsl:apply-templates select="tempMinPeriod/period">
      <xsl:with-param name="pre" select="' '"/>
      <xsl:with-param name="header" select="$trans/hdr[@o='tempMinPeriod']"/>
     </xsl:apply-templates>
    </xsl:with-param>
    <xsl:with-param name="temp" select="tempMinPeriod"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="soilTemp">
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="concat(substring-before($trans/hdr[@o='soilTemp'], '|'), depth/@v, substring-after($trans/hdr[@o='soilTemp'], '|'))"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="printTemp">
  <xsl:param name="hdr"/>
  <xsl:param name="notavail"/>
  <xsl:param name="rows"/>
  <xsl:param name="s"/>
  <xsl:param name="temp"/>
  <xsl:if test="$s != ''">
   <xsl:call-template name="src_string">
    <xsl:with-param name="rows" select="$rows"/>
    <xsl:with-param name="s" select="$s"/>
   </xsl:call-template>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$hdr"/>
  </td>
  <xsl:choose>
   <xsl:when test="boolean($temp/notAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="$temp/temp/@u = 'C'">
      <xsl:value-of select="$temp/temp/@v"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="format-number(($temp/temp/@v - 32) div 1.8, '0.0')"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:text> °C</xsl:text>
    <xsl:apply-templates select="$temp/timeAt">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
    </td>
    <xsl:choose>
     <xsl:when test="boolean($temp/timeAt)">
      <xsl:text>&#9;&#9;&#9;</xsl:text>
     </xsl:when>
     <xsl:otherwise>
      <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     </xsl:otherwise>
    </xsl:choose>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="$temp/temp/@u = 'C'">
      <!--xsl:value-of select="format-number($temp/temp/@v * 1.8 + 32, '0.#')"/-->
      <xsl:value-of select="format-number(floor(10 * ($temp/temp/@v * 1.8 + 32 + 0.05)) div 10, '0.0')"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$temp/temp/@v"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:text> °F</xsl:text>
    </td>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="QNH|stationPressure|somePressure|SLP|regQNH|QFE|QFF">
  <xsl:variable name="rows">
   <xsl:if test="boolean(hPa) and boolean(inHg)">2</xsl:if>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="notAvailable|invalidFormat"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="boolean(hPa)">
      <xsl:value-of select="hPa/@v"/>
     </xsl:when>
     <xsl:when test="boolean(mmHg)">
      <xsl:value-of select="format-number(mmHg/@v div ($FT2M div 12 * 1000) * $INHG2HPA, '0')"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="format-number(inHg/@v * $INHG2HPA, '0')"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$trans/units[@o='hPa']"/>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="boolean(hPa) and boolean(inHg)">
      <xsl:value-of select="format-number(hPa/@v div $INHG2HPA, '0.00')"/>
     </xsl:when>
     <xsl:when test="boolean(inHg)">
      <xsl:value-of select="inHg/@v"/>
     </xsl:when>
     <xsl:when test="boolean(hPa)">
      <xsl:value-of select="format-number(hPa/@v div $INHG2HPA, '0.00')"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="format-number(mmHg/@v div ($FT2M div 12 * 1000), '0.00')"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$trans/units[@o='inHg']"/>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(hPa) and boolean(inHg)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:value-of select="format-number(inHg/@v * $INHG2HPA, '0')"/>
   <xsl:value-of select="$trans/units[@o='hPa']"/>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:value-of select="inHg/@v"/>
   <xsl:value-of select="$trans/units[@o='inHg']"/>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="cloudMaxCover">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(SKC)">
    <xsl:value-of select="$trans/cloudCover[@o='SKC']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/cloudCover[@o=current()/cloudCover/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudAbove">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name">
    <xsl:choose>
     <xsl:when test="boolean(isThin)">cloudLayerThin</xsl:when>
     <xsl:otherwise>cloudLayer</xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="printCloud">
   <xsl:with-param name="at_abv" select="'cloud-above'"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudCoverVar">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string"/>
  <xsl:choose>
   <xsl:when test="boolean(cloudBase)">
    <xsl:call-template name="printCloud">
     <xsl:with-param name="at_abv" select="'cloud-at'"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/cloudCover[@o=current()/cloudCover/@v]"/>
   </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'cloudCoverVar2'"/>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/cloudCover[@o=current()/cloudCover2/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="reportConcerns">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:variable name="chg" select="$trans/concernsChange[@o=current()/change/@v]"/>
  <xsl:value-of select="concat(substring-before($chg, '|'), $trans/concernsSubject[@o=current()/subject/@v], substring-after($chg, '|'))"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudOpacityLvl">
 <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1">
  <xsl:value-of select="concat(oktas/@v, '/8')"/>
  <xsl:if test="boolean(weather)">
   <xsl:text> </xsl:text>
   <xsl:for-each select="weather">
    <xsl:call-template name="printWeather"/>
   </xsl:for-each>
  </xsl:if>
  <xsl:if test="boolean(cloudType)">
   <xsl:value-of select="concat(' ', $trans/cloudType[@o=current()/cloudType/@v])"/>
  </xsl:if>
  <xsl:value-of select="concat(' ', $trans/t[@o='cloud-at'], ' ')"/>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'FT'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
  </xsl:call-template>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
  </xsl:apply-templates>
  </td>
  <xsl:text>&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'M'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
  </xsl:call-template>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="RH">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'relHumid'"/>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="relHumid/@v"/>
  <xsl:text>%</xsl:text>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="AI">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
   <xsl:value-of select="AIVal/@v"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="rwyState">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:choose>
   <xsl:when test="boolean(SNOCLO)">
    <td nowrap="1" colspan="3">
    <xsl:value-of select="$trans/t[@o='SNOCLO']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:value-of select="substring-before($trans/hdr[@o='stateOfRwy'], '|')"/>
    <xsl:choose>
     <xsl:when test="boolean(rwyDesigAll)">
      <xsl:value-of select="$trans/t[@o='rwyDesigAll']"/>
     </xsl:when>
     <xsl:when test="boolean(rwyDesigRep)">
      <xsl:value-of select="$trans/t[@o='rwyDesigRep']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="substring-after($trans/hdr[@o='stateOfRwy'], '|')"/>
    </td>
    <td colspan="2">
    <xsl:choose>
     <xsl:when test="boolean(depositType/notAvailable) and boolean(depositExtent/notAvailable) and boolean(depositDepth/notAvailable) and boolean(friction/notAvailable)">
      <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </xsl:when>

     <xsl:otherwise>

      <xsl:if test="boolean(cleared)">
       <xsl:value-of select="$trans/t[@o='cleared']"/>
      </xsl:if>

      <xsl:if test="boolean(invalidFormat)">
       <xsl:apply-templates select="invalidFormat"/>
      </xsl:if>

      <xsl:variable name="delim1">
       <xsl:if test="boolean(cleared)">, </xsl:if>
      </xsl:variable>
      <xsl:if test="boolean(depositType/depositTypeVal)">
       <xsl:value-of select="$delim1"/>
       <xsl:value-of select="$trans/depositType[@o=current()/depositType/depositTypeVal/@v]"/>
      </xsl:if>

      <xsl:variable name="delim2">
       <xsl:if test="$delim1 != '' or boolean(depositType/depositTypeVal)">, </xsl:if>
      </xsl:variable>
      <xsl:apply-templates select="depositExtent/invalidFormat">
       <xsl:with-param name="s" select="$delim2"/>
      </xsl:apply-templates>
      <xsl:if test="boolean(depositExtent/depositExtentVal)">
       <xsl:value-of select="$delim2"/>
       <xsl:value-of select="substring-before($trans/depositExtent[@o=current()/depositExtent/depositExtentVal/@v], '|')"/>
       <xsl:value-of select="$trans/t[@o='depositExtent']"/>
       <xsl:value-of select="substring-after($trans/depositExtent[@o=current()/depositExtent/depositExtentVal/@v], '|')"/>
      </xsl:if>

      <xsl:variable name="delim3">
       <xsl:if test="$delim2 != '' or boolean(depositExtent/invalidFormat|depositExtent/depositExtentVal)">, </xsl:if>
      </xsl:variable>
      <xsl:apply-templates select="depositDepth/invalidFormat">
       <xsl:with-param name="s" select="$delim3"/>
      </xsl:apply-templates>
      <xsl:if test="boolean(depositDepth/depositDepthVal)">
       <xsl:value-of select="$delim3"/>
       <xsl:value-of select="substring-before($trans/t[@o='depositDepth'], '|')"/>
       <xsl:call-template name="unitConverter">
        <xsl:with-param name="val" select="depositDepth/depositDepthVal"/>
       </xsl:call-template>
       <xsl:value-of select="substring-after($trans/t[@o='depositDepth'], '|')"/>
      </xsl:if>
      <xsl:if test="boolean(depositDepth/rwyNotInUse)">
       <xsl:value-of select="$delim3"/>
       <xsl:value-of select="$trans/t[@o='rwyNotInUse']"/>
      </xsl:if>
      <xsl:variable name="delim4">
       <xsl:if test="$delim3 != '' or boolean(depositDepth/invalidFormat|depositDepth/depositDepthVal|depositDepth/rwyNotInUse)">, </xsl:if>
      </xsl:variable>
      <xsl:apply-templates select="friction/invalidFormat">
       <xsl:with-param name="s" select="$delim4"/>
      </xsl:apply-templates>
      <xsl:if test="boolean(friction/coefficient)">
       <xsl:value-of select="concat($delim4, $trans/t[@o='friction'], format-number(friction/coefficient/@v div 100, '0.00'))"/>
      </xsl:if>
      <xsl:if test="boolean(friction/brakingAction)">
       <xsl:value-of select="concat($delim4, $trans/friction[@o=current()/friction/brakingAction/@v])"/>
      </xsl:if>
      <xsl:if test="boolean(friction/unreliable)">
       <xsl:value-of select="concat($delim4, $trans/friction[@o='99'])"/>
      </xsl:if>
     </xsl:otherwise>
    </xsl:choose>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="windShear">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='windShearRwy'], '|')"/>
  <xsl:choose>
   <xsl:when test="boolean(rwyDesigAll)">
    <xsl:value-of select="$trans/t[@o='rwyDesigAll']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='windShearRwy'], '|')"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/t[@o='windShear']"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="colourCode">
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(BLACK) and boolean(currentColour) and boolean(predictedColour)">3</xsl:when>
    <xsl:when test="boolean(BLACK) and boolean(currentColour)">2</xsl:when>
    <xsl:when test="boolean(currentColour) and boolean(predictedColour)">2</xsl:when>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(BLACK)">
    <xsl:value-of select="$trans/colour[@o='BLACK']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/colour[@o=current()/currentColour/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(currentColour) and boolean(BLACK)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/colour[@o=current()/currentColour/@v]"/>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(predictedColour)">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/t[@o='predictedColour']"/>
   <br />
   <xsl:if test="$method != 'html'">
    <xsl:text>&#10;&#9;&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:choose>
    <xsl:when test="currentColour/@v != predictedColour/@v">
     <xsl:value-of select="$trans/colour[@o=current()/predictedColour/@v]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/colour[@o='noChange']"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="windShearLvl">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='topOfLayer'], ' ', level/@v * 100, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(level/@v * 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <xsl:call-template name="printSpeed">
   <xsl:with-param name="dir">
    <xsl:value-of select="concat($trans/t[@o='wind-from'], ' ')"/>
    <xsl:if test="wind/dir/@q = 'isGrid'">
     <xsl:value-of select="$trans/t[@o='isGrid']"/>
    </xsl:if>
    <xsl:value-of select="$trans/compassDir16/arr[1+format-number(current()/wind/dir/@v div 45 * 2, '0')]"/>
    <xsl:value-of select="concat(' (', wind/dir/@v, '°)')"/>
   </xsl:with-param>
   <xsl:with-param name="speed" select="wind/speed"/>
   <xsl:with-param name="delim" select="'&#9;&#9;'"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="printLayerHeight">
  <xsl:param name="height"/>
  <xsl:value-of select="concat($height, $trans/units[@o='M'], ' (', format-number($height div $FT2M div 100, '#0'), '00', $trans/units[@o='FT'], ') AGL')"/>
 </xsl:template>

 <xsl:template match="turbulence|icing">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/turbulenceDescr[@o=current()/turbulenceDescr/@v]"/>
  <xsl:value-of select="$trans/icingDescr[@o=current()/icingDescr/@v]"/>
  <xsl:value-of select="concat(', ', $trans/t[@o='level-from'], ' ')"/>
  <xsl:choose>
   <!-- WMO-No. 306 Vol I.1, Part A, coding table 1690 -->
   <xsl:when test="layerBase/@v = 0">
    <xsl:value-of select="concat('&lt;30', $trans/units[@o='M'], ' (&lt;100', $trans/units[@o='FT'], ') AGL')"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerBase/@v * 30"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:choose>
   <xsl:when test="boolean(layerTop)">
    <xsl:value-of select="concat(' ', $trans/t[@o='level-to'], ' ')"/>
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerTop/@v * 30"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="layerThickness/@v = 0">
    <xsl:value-of select="$trans/t[@o='toTopOfCloud']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(' ', $trans/t[@o='level-to'], ' ')"/>
    <!-- WMO-No. 306 Vol I.1, Part A, coding table 0300 -->
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerBase/@v * 30 + layerThickness/@v * 300"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="amendment">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="concat($trans/t[@o='amendment'], ' ')"/>
  <xsl:choose>
   <xsl:when test="boolean(isNotScheduled)">
    <xsl:value-of select="$trans/t[@o='isNotScheduled']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='isLtdToCldVisWind']"/>
    <xsl:apply-templates select="timeFrom|timeTill">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <!-- combine all trend nodes into one set and process them in one go -->
 <xsl:template match="trend">
  <xsl:apply-templates select="../trend" mode="go"/>
 </xsl:template>

 <xsl:template match="trend" mode="go">
  <xsl:if test="position() = 1">
   <xsl:text>&#10;</xsl:text>
   <tr>
   <td></td>
   <td nowrap="1" colspan="3"><b>
    <xsl:if test="name(..) = 'metar'">
     <xsl:value-of select="$trans/hdr[@o='trend']"/>
    </xsl:if>
    <xsl:if test="name(..) != 'metar'">
     <xsl:value-of select="$trans/hdr[@o='trendTAF']"/>
    </xsl:if>
    <xsl:if test="$method != 'html'">
     <xsl:if test="name(..) = 'metar'">
      <xsl:value-of select="concat('&#10;', $trans/hdr[@o='trend_ul'])"/>
     </xsl:if>
     <xsl:if test="name(..) != 'metar'">
      <xsl:value-of select="concat('&#10;', $trans/hdr[@o='trendTAF_ul'])"/>
     </xsl:if>
    </xsl:if>
   </b></td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:if test="position() != 1">
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:choose>
   <xsl:when test="trendType/@v = 'NOSIG'">
    <xsl:value-of select="$trans/t[@o='NOSIG']"/>
   </xsl:when>
   <xsl:otherwise>
    <b>
    <xsl:if test="boolean(probability)">
     <xsl:value-of select="concat(substring-before($trans/t[@o='prob'], '|'), probability/@v, substring-after($trans/t[@o='prob'], '|'))"/>
    </xsl:if>
    <xsl:apply-templates select="timeAt|timeFrom|timeTill">
     <xsl:with-param name="pre">
      <xsl:if test="boolean(probability)"><xsl:text> </xsl:text></xsl:if>
     </xsl:with-param>
    </xsl:apply-templates>
    <xsl:if test="$trans/t[@o=current()/trendType/@v] != ':' and boolean(probability|timeAt|timeFrom|timeTill)">
     <xsl:text> </xsl:text>
    </xsl:if>
    <xsl:value-of select="$trans/t[@o=current()/trendType/@v]"/>
    </b>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="sfcWind|CAVOK|visPrev|visVert|weather[1]|cloud[1]|rwyState|colourCode|turbulence|icing|windShearLvl|QNH|obscuration"/>
  <xsl:if test="position() = last() and boolean(following-sibling::*) and not(boolean(following-sibling::remark)) and not(boolean(following-sibling::tafRemark))">
   <xsl:text>&#10;</xsl:text>
   <tr><td/><td colspan="3"><hr/></td></tr>
  </xsl:if>
 </xsl:template>

 <!-- combine all tafRemark nodes into one set and process them in one go -->
 <xsl:template match="tafRemark">
  <xsl:apply-templates select="../tafRemark" mode="go"/>
 </xsl:template>

 <xsl:template match="tafRemark" mode="go">
  <xsl:if test="position() = 1">
   <xsl:text>&#10;</xsl:text>
   <tr>
   <xsl:if test="$method = 'html'">
    <td><b>RMK</b></td>
   </xsl:if>
   <td nowrap="1" colspan="3"><b>
    <xsl:value-of select="$trans/hdr[@o='remark']"/>
    <xsl:if test="$method != 'html'">
     <xsl:value-of select="concat('&#10;', $trans/hdr[@o='remark_ul'])"/>
    </xsl:if>
   </b></td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:apply-templates select="*"/>
 </xsl:template>

 <!-- combine all remark nodes into one set and process them in one go -->
 <xsl:template match="remark">
  <xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:if test="$method = 'html'">
   <td><b>RMK</b></td>
  </xsl:if>
  <td nowrap="1" colspan="3"><b>
   <xsl:value-of select="$trans/hdr[@o='remark']"/>
   <xsl:if test="$method != 'html'">
    <xsl:value-of select="concat('&#10;', $trans/hdr[@o='remark_ul'])"/>
   </xsl:if>
  </b></td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="../remark" mode="go"/>
 </xsl:template>

 <xsl:template match="remark" mode="go">
  <xsl:variable name="rmk" select="name(child::*[last()])"/>
  <xsl:choose>
   <xsl:when test="$rmk = 'cloud'">
    <xsl:apply-templates select="cloud">
     <xsl:with-param name="s_list" select="cloud/@s"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$rmk = 'visRwy'">
    <xsl:apply-templates select="visRwy"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="child::*[last()]"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="ERROR">
  <tr>
  <td nowrap="1" colspan="4">
  <pre style="margin: 0; font-size: 90%;">
  <xsl:value-of select="concat($trans/hdr[@o='ERROR'], $trans/error[@o=current()/@errorType], ': ', @s)"/>
  </pre>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="warning">
  <tr>
  <td nowrap="1" colspan="4">
  <pre style="margin: 0; font-size: 90%;">
  <xsl:value-of select="$trans/hdr[@o='warning']"/>
  <xsl:choose>
   <xsl:when test="@s != ''">
    <xsl:value-of select="concat(substring-before($trans/warning[@o=current()/@warningType], '|'), @s, substring-after($trans/warning[@o=current()/@warningType], '|'))"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/warning[@o=current()/@warningType]"/>
   </xsl:otherwise>
  </xsl:choose>
  </pre>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="invalidFormat">
  <xsl:param name="s"/>
  <xsl:value-of select="concat($s, '(', $trans/t[@o='invalidFormat'])"/>
  <xsl:text>: '</xsl:text>
  <xsl:value-of select="@v"/>
  <xsl:text>')</xsl:text>
 </xsl:template>

 <xsl:template match="CAVOK|RVRNO|needMaint|fcstAutoMETAR|fcstCancelled">
  <xsl:variable name="name" select="name()"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b>
   <xsl:choose>
    <xsl:when test="boolean(@s)">
     <xsl:value-of select="@s"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$name"/>
    </xsl:otherwise>
   </xsl:choose>
   </b></td>
  </xsl:if>
  <td colspan="3">
   <xsl:value-of select="$trans/t[@o=$name]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="keyword">
  <tr>
  <xsl:call-template name="src_string"/>
  <td colspan="3">
  <xsl:choose>
   <xsl:when test="$trans/t[@o=current()/@v] != ''">
    <xsl:value-of select="$trans/t[@o=current()/@v]"/>
    <xsl:if test="@v = 'EPO' or @v = 'EPC' or @v = 'EPM'">
     <!-- Sheep Mountain Airport -->
     <xsl:if test="../../obsStationId/id/@v = 'PASP'"> (Tahetna pass)</xsl:if>
     <!-- Cantwell -->
     <xsl:if test="../../obsStationId/id/@v = 'PATW'"></xsl:if>
     <!-- Merrill Pass West -->
     <xsl:if test="../../obsStationId/id/@v = 'PAER'"></xsl:if>
     <!-- Farewell Lake Seaplane Base -->
     <xsl:if test="../../obsStationId/id/@v = 'PAFK'"></xsl:if>
     <!-- Healy River Airport -->
     <xsl:if test="../../obsStationId/id/@v = 'PAHV'"></xsl:if>
     <!-- Port Alsworth -->
     <xsl:if test="../../obsStationId/id/@v = 'PALJ'"></xsl:if>
     <!-- Big River Lake -->
     <xsl:if test="../../obsStationId/id/@v = 'PALV'"></xsl:if>
    </xsl:if>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="@s"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsStationType">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/stationType[@o=current()/stationType/@v]"/>
  </td></tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visListAtLoc">
  <xsl:apply-templates select="visLocData"/>
 </xsl:template>

 <xsl:template match="visLocData">
  <tr>
  <xsl:if test="position() = 1">
   <xsl:call-template name="src_string">
    <xsl:with-param name="rows">
     <xsl:if test="last() != 1"><xsl:value-of select="last()"/></xsl:if>
    </xsl:with-param>
    <xsl:with-param name="s" select="../@s"/>
   </xsl:call-template>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='visLoc'], '|')"/>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirTo'"/>
  </xsl:apply-templates>
  <xsl:value-of select="substring-after($trans/hdr[@o='visLoc'], '|')"/>
  </td>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibility"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="MOV|MOVD">
  <xsl:value-of select="$trans/t[@o=name(current())]"/>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirTo'"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="locationAnd">
  <xsl:param name="locOrDir"/>
  <xsl:apply-templates select="locationThru">
   <xsl:with-param name="locOrDir" select="$locOrDir"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="locationThru">
  <xsl:param name="locOrDir"/>
  <xsl:if test="position() != 1">
    <xsl:text>,</xsl:text>
  </xsl:if>
  <xsl:apply-templates select="location">
   <xsl:with-param name="locOrDirBefore" select="substring-before($trans/t[@o=$locOrDir], '|')"/>
   <xsl:with-param name="locOrDirAfter" select="substring-after($trans/t[@o=$locOrDir], '|')"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="location">
  <xsl:param name="locOrDirBefore"/>
  <xsl:param name="locOrDirAfter"/>
  <xsl:if test="position() != 1">
   <xsl:value-of select="substring-before($trans/t[@o='compassDirThrough'], '|')"/>
  </xsl:if>
  <xsl:if test="boolean(distance)">
   <xsl:value-of select="concat(' ', distance/@v, $trans/units[@o=current()/distance/@u])"/>
  </xsl:if>
  <xsl:if test="position() = 1 and boolean(inDistance|inVicinity)">
   <xsl:value-of select="concat(' ', $trans/locationSpec[@o=name(current()/inDistance|current()/inVicinity)])"/>
  </xsl:if>
  <xsl:apply-templates select="locationSpec">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  <xsl:if test="position() = 1 and boolean(compassDir|quadrant)">
   <xsl:value-of select="$locOrDirBefore"/>
  </xsl:if>
  <xsl:if test="boolean(quadrant)">
   <xsl:text> </xsl:text>
   <xsl:for-each select="quadrant">
    <xsl:if test="position() != 1">
     <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
    </xsl:if>
    <xsl:value-of select="$trans/quadrant[@o=current()/@v]"/>
   </xsl:for-each>
   <xsl:value-of select="concat(' ', $trans/t[@o='quadrant'])"/>
  </xsl:if>
  <xsl:if test="boolean(compassDir)">
   <xsl:variable name="quad">
    <xsl:choose>
     <xsl:when test="boolean(isQuadrant)">Quad</xsl:when>
     <xsl:otherwise/>
    </xsl:choose>
   </xsl:variable>
   <xsl:variable name="ccd" select="$trans/t[@o=concat('compassDirDescr', $quad)]"/>
   <xsl:apply-templates select="compassDir">
    <xsl:with-param name="pre" select="substring-before($ccd, '|')"/>
    <xsl:with-param name="post" select="substring-after($ccd, '|')"/>
   </xsl:apply-templates>
  </xsl:if>
  <xsl:if test="position() = 1 and boolean(compassDir|quadrant)">
   <xsl:value-of select="$locOrDirAfter"/>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:value-of select="substring-after($trans/t[@o='compassDirThrough'], '|')"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="visibilityAtLoc">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:if test="boolean(locationAt)">
   <xsl:value-of select="$trans/visibilityAtLoc[@o=current()/locationAt/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(rwyDesig)">
   <xsl:value-of select="$trans/t[@o='visibilityAt']"/>
   <xsl:if test="boolean(isApproach)">
    <xsl:value-of select="concat(' ', $trans/t[@o='approach'])"/>
   </xsl:if>
   <xsl:value-of select="concat(' ', substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
   <xsl:text>:&#9;</xsl:text>
  </xsl:if>
  </td>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibility"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visMin">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'rmkVisMin'"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visVar2">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
   <xsl:with-param name="s" select="../visVar1/@s"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'rmkVisVar'"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="../visVar1"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'to'"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="precipHourly|precipCity">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o=name(current())], '|')"/>
  <xsl:choose>
   <xsl:when test="boolean(periodNotAvailable)">
    <xsl:if test="not(boolean(notAvailable))">
     <xsl:value-of select="$trans/t[@o='periodNotAvailable']"/>
    </xsl:if>
   </xsl:when>
   <xsl:when test="boolean(period3o6h)">
    <xsl:value-of select="$trans/t[@o='precip3o6Hour']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="period|timeBeforeObsSince|timeSince">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='precipHourly'], '|')"/>
  </td>
  <xsl:call-template name="precipAmountVal"/>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="precipAmountVal">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat|coverNotCont|noMeasurement|traces)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="notAvailable|invalidFormat|coverNotCont|noMeasurement|traces"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="precipAmount"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="precipAmount/@u = 'IN' and precipAmount/@v &lt; 1">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="precipAmount"/>
       <xsl:with-param name="unit" select="'MM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0'"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:when test="precipAmount/@u = 'IN'">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="precipAmount"/>
       <xsl:with-param name="unit" select="'CM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="precipAmount"/>
       <xsl:with-param name="unit" select="'IN'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    </td>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="snowIncr">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="substring-before($trans/t[@o='snowIncrPastHour'],'|')"/>
  <xsl:value-of select="pastHour/@v"/>
  <xsl:value-of select="substring-after($trans/t[@o='snowIncrPastHour'], '|')"/>
  <xsl:text>, </xsl:text>
  <xsl:value-of select="substring-before($trans/t[@o='snowIncrOnGround'],'|')"/>
  <xsl:value-of select="onGround/@v"/>
  <xsl:value-of select="substring-after($trans/t[@o='snowIncrOnGround'], '|')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypes">
  <xsl:variable name="rows">
   <xsl:if test="boolean(cloudTypeLow|cloudTypeLowAboveOvercast|cloudTypeMiddle|cloudTypeMiddleAboveOvercast|cloudTypeHigh|cloudTypeHighAboveOvercast)">3</xsl:if>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat|skyObscured)">
    <td colspan="2">
    <xsl:apply-templates select="notAvailable|invalidFormat|skyObscured"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(cloudTypeLowNA) and boolean(cloudTypeMiddleNA) and boolean(cloudTypeHighNA)">
    <td colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    <xsl:if test="boolean(oktas)">
     <xsl:text> </xsl:text>
     <xsl:value-of select="concat(oktas/@v, '/8')"/>
     <xsl:if test="oktas/@v = 1">
      <xsl:value-of select="$trans/t[@o='lessOktas']"/>
     </xsl:if>
     <xsl:if test="oktas/@v = 7">
      <xsl:value-of select="$trans/t[@o='moreOktas']"/>
     </xsl:if>
    </xsl:if>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>&#10;&#9;</xsl:text>
    <td colspan="2">
    <xsl:value-of select="$trans/t[@o='low']"/>
    <xsl:choose>
     <xsl:when test="boolean(cloudTypeLowNA)">
      <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </xsl:when>
     <xsl:when test="boolean(cloudTypeLowAboveOvercast)">
      <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:if test="boolean(oktasLow)">
       <xsl:value-of select="concat(oktasLow/@v, '/8')"/>
       <xsl:if test="oktasLow/@v = 1">
        <xsl:value-of select="$trans/t[@o='lessOktas']"/>
       </xsl:if>
       <xsl:if test="oktasLow/@v = 7">
        <xsl:value-of select="$trans/t[@o='moreOktas']"/>
       </xsl:if>
       <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:value-of select="$trans/cloudTypeLow[@o=current()/cloudTypeLow/@v]"/>
     </xsl:otherwise>
    </xsl:choose>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="$rows = 3">
   <tr>
   <xsl:text>&#9;</xsl:text>
   <td colspan="2">
   <xsl:value-of select="$trans/t[@o='middle']"/>
   <xsl:choose>
    <xsl:when test="boolean(cloudTypeMiddleNA)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="boolean(cloudTypeMiddleAboveOvercast)">
     <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:if test="boolean(oktasMiddle)">
      <xsl:value-of select="concat(oktasMiddle/@v, '/8')"/>
      <xsl:if test="oktasMiddle/@v = 1">
       <xsl:value-of select="$trans/t[@o='lessOktas']"/>
      </xsl:if>
      <xsl:if test="oktasMiddle/@v = 7">
       <xsl:value-of select="$trans/t[@o='moreOktas']"/>
      </xsl:if>
      <xsl:text> </xsl:text>
     </xsl:if>
     <xsl:value-of select="$trans/cloudTypeMiddle[@o=current()/cloudTypeMiddle/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
   <tr>
   <td colspan="2">
   <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='high']"/>
   <xsl:choose>
    <xsl:when test="boolean(cloudTypeHighNA)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="boolean(cloudTypeHighAboveOvercast)">
     <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/cloudTypeHigh[@o=current()/cloudTypeHigh/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="section2|section3|section4|section5">
  <xsl:call-template name="section">
   <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="section_nr" select="substring(name(), 8)"/>
  </xsl:call-template>
  <xsl:apply-templates select="*"/>
 </xsl:template>

 <xsl:template match="weatherHist">
  <xsl:variable name="rows">
   <xsl:apply-templates select="weatherBeginEnd" mode="count"/>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'weather'"/>
   <xsl:with-param name="rows"  select="$rows"/>
  </xsl:call-template>
  <xsl:apply-templates select="weatherBeginEnd">
   <xsl:with-param name="is_first" select="1"/>
  </xsl:apply-templates>
  </tr>
  <xsl:apply-templates select="weatherBeginEnd">
   <xsl:with-param name="is_first" select="0"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(MOV|MOVD|isStationary|locationAnd)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1" colspan="2">
   <xsl:if test="boolean(locationAnd)">
    <xsl:apply-templates select="locationAnd">
     <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
    </xsl:apply-templates>
    <xsl:if test="boolean(MOV|MOVD|isStationary)">
     <xsl:text>,</xsl:text>
    </xsl:if>
   </xsl:if>
   <xsl:apply-templates select="MOV|MOVD|isStationary"/>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="weatherBeginEnd" mode="count">
  <xsl:if test="position() = 1">
   <xsl:choose>
    <xsl:when test="boolean(../MOV|../MOVD|../isStationary|../locationAnd)">
     <xsl:value-of select="last() + 1"/>
    </xsl:when>
    <xsl:when test="last() != 1">
     <xsl:value-of select="last()"/>
    </xsl:when>
   </xsl:choose>
  </xsl:if>
 </xsl:template>

 <xsl:template match="weatherBeginEnd">
  <xsl:param name="is_first"/>
  <xsl:if test="$is_first = 1 and position() = 1">
   <td nowrap="1" colspan="2">
   <dl style="margin: 0;"><dt>
   <xsl:call-template name="printWeather"/>
   <xsl:text>:</xsl:text></dt>
   <xsl:apply-templates select="beganAt|endedAt"/>
   </dl></td>
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="$is_first = 0 and position() != 1">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <td nowrap="1" colspan="2">
   <dl style="margin: 0;"><dt>
   <xsl:call-template name="printWeather"/>
   <xsl:text>:</xsl:text></dt>
   <xsl:apply-templates select="beganAt|endedAt"/>
   </dl></td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="beganAt|endedAt">
  <xsl:if test="$method != 'html'">
   <xsl:text>&#10;&#9;&#9;&#9;&#9;</xsl:text>
  </xsl:if>
  <dd>
  <xsl:value-of select="$trans/t[@o=name(current())]"/>
  <xsl:apply-templates select="timeAt"/>
  </dd>
 </xsl:template>

 <xsl:template match="cloudType">
  <xsl:if test="position() != 1">
   <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
  </xsl:if>
  <xsl:value-of select="$trans/cloudType[@o=current()/@v]"/>
 </xsl:template>

 <xsl:template match="lightningType">
  <xsl:if test="position() = 1">
   <xsl:value-of select="concat($trans/phenomenon[@o='LTG'], ' ')"/>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
  </xsl:if>
  <xsl:value-of select="$trans/lightningType[@o=current()/@v]"/>
 </xsl:template>

 <xsl:template match="phenomenon">
  <tr>
  <xsl:call-template name="src_string"/>
  <td colspan="3">
  <xsl:apply-templates select="phenomDescrPre">
   <xsl:with-param name="post" select="' '"/>
  </xsl:apply-templates>
  <xsl:choose>
   <xsl:when test="boolean(weather)">
   <xsl:for-each select="weather">
    <xsl:call-template name="printWeather"/>
   </xsl:for-each>
   </xsl:when>
   <xsl:when test="boolean(cloudType)">
    <xsl:apply-templates select="cloudType"/>
   </xsl:when>
   <xsl:when test="boolean(cloudCover)">
    <xsl:value-of select="$trans/cloudCover[@o=current()/cloudCover/@v]"/>
   </xsl:when>
   <xsl:when test="boolean(lightningType)">
    <xsl:apply-templates select="lightningType"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/phenomenon[@o=current()/otherPhenom/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="boolean(obscgMtns)">
   <xsl:value-of select="$trans/t[@o='obscgMtns']"/>
  </xsl:if>
  <xsl:apply-templates select="phenomDescrPost">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(locationAnd)">
   <xsl:if test="boolean(phenomDescrPost)">
    <xsl:text>,</xsl:text>
   </xsl:if>
   <xsl:apply-templates select="locationAnd">
    <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
   </xsl:apply-templates>
   <xsl:if test="boolean(MOV|MOVD|isStationary)">
    <xsl:text>,</xsl:text>
   </xsl:if>
  </xsl:if>
  <xsl:apply-templates select="MOV|MOVD|isStationary"/>
  <xsl:if test="boolean(baseBelowStation)">
   <xsl:value-of select="$trans/t[@o='baseBelowStation']"/>
  </xsl:if>
  <xsl:if test="boolean(isAloft)">
   <xsl:value-of select="$trans/t[@o='isAloft']"/>
  </xsl:if>
  <xsl:if test="boolean(isAround)">
   <xsl:value-of select="$trans/t[@o='isAround']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeAsoctd|cloudTypeEmbd)">
   <xsl:text>, </xsl:text>
   <xsl:apply-templates select="cloudTypeAsoctd|cloudTypeEmbd"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="phenomDescr|phenomDescr2|phenomVariation|phenomDescrPre|phenomDescrPost|locationSpec">
  <xsl:param name="pre"/>
  <xsl:param name="post"/>
  <xsl:if test="position() = 1"><xsl:value-of select="$pre"/></xsl:if>
  <xsl:if test="position() != 1"><xsl:text>, </xsl:text></xsl:if>
  <xsl:choose>
   <xsl:when test="name() = 'locationSpec'">
    <xsl:value-of select="$trans/locationSpec[@o=current()/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o=current()/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="position() = last()"><xsl:value-of select="$post"/></xsl:if>
 </xsl:template>

 <xsl:template match="conditionMountain">
  <xsl:apply-templates select="condMountainLoc"/>
  <xsl:apply-templates select="maxConcentration"/>
 </xsl:template>

 <xsl:template match="condMountainLoc">
  <tr>
  <xsl:if test="position() = 1">
   <xsl:call-template name="src_string">
    <xsl:with-param name="rows">
     <xsl:apply-templates select="../maxConcentration" mode="count">
      <xsl:with-param name="offset" select="1"/>
     </xsl:apply-templates>
    </xsl:with-param>
    <xsl:with-param name="s" select="../@s"/>
   </xsl:call-template>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'conditionMountain'"/>
    <xsl:with-param name="rows">
     <xsl:if test="last() != 1"><xsl:value-of select="last()"/></xsl:if>
    </xsl:with-param>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
  </xsl:if>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(locationAnd)">
   <xsl:text>: </xsl:text>
  </xsl:if>
  <xsl:value-of select="$trans/cloudMountain[@o=current()/cloudMountain/@v]"/>
  <xsl:if test="boolean(cloudEvol)">
   <xsl:value-of select="concat('. ', $trans/phenomenon[@o='CLDS'], ': ', $trans/cloudEvol[@o=current()/cloudEvol/@v])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="conditionValley">
  <xsl:apply-templates select="condValleyLoc"/>
  <xsl:apply-templates select="maxConcentration"/>
 </xsl:template>

 <xsl:template match="condValleyLoc">
  <tr>
  <xsl:if test="position() = 1">
   <xsl:call-template name="src_string">
    <xsl:with-param name="rows">
     <xsl:apply-templates select="../maxConcentration" mode="count">
      <xsl:with-param name="offset" select="1"/>
     </xsl:apply-templates>
    </xsl:with-param>
    <xsl:with-param name="s" select="../@s"/>
   </xsl:call-template>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'conditionValley'"/>
    <xsl:with-param name="rows">
     <xsl:if test="last() != 1"><xsl:value-of select="last()"/></xsl:if>
    </xsl:with-param>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
  </xsl:if>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(locationAnd)">
   <xsl:text>: </xsl:text>
  </xsl:if>
  <xsl:value-of select="$trans/cloudValley[@o=current()/cloudValley/@v]"/>
  <xsl:if test="boolean(cloudBelowEvol)">
   <xsl:value-of select="concat('. ', $trans/phenomenon[@o='CLDS'], ': ', $trans/cloudBelowEvol[@o=current()/cloudBelowEvol/@v])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="ceilingAtLoc">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="$trans/t[@o='ceiling']"/>
  <xsl:if test="boolean(isApproach)">
   <xsl:value-of select="concat(' ', $trans/t[@o='approach'])"/>
  </xsl:if>
  <xsl:if test="boolean(rwyDesig)">
   <xsl:value-of select="concat(' ', substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
  </xsl:if>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
  </xsl:apply-templates>
  <xsl:text>:</xsl:text>
  </td>
  <xsl:text>&#9;</xsl:text>
  <xsl:choose>
   <xsl:when test="boolean(cloudsLower)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="concat($trans/phenomenon[@o='CLDS'], ' ', $trans/t[@o='isLower'])"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' ')"/>
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'FT'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'M'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="opacityPhenom">
  <xsl:choose>
   <xsl:when test="boolean(cloudTypeAsoctd|cloudTypeEmbd)">
    <xsl:apply-templates select="opacityCloud|opacityWeather">
     <xsl:with-param name="add_rows" select="1"/>
    </xsl:apply-templates>
    <tr>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="cloudTypeAsoctd|cloudTypeEmbd"/>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="opacityCloud|opacityWeather">
     <xsl:with-param name="add_rows" select="0"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="cloudTypeAsoctd|cloudTypeEmbd">
  <xsl:value-of select="concat(substring-before($trans/t[@o=name(current())], '|'), $trans/cloudType[@o=current()/@v], substring-after($trans/t[@o=name(current())], '|'))"/>
 </xsl:template>

 <xsl:template match="opacityCloud|opacityWeather">
  <xsl:param name="add_rows"/>
  <xsl:variable name="rows">
   <xsl:if test="last() + $add_rows != 1">
    <xsl:value-of select="last() + $add_rows"/>
   </xsl:if>
  </xsl:variable>
  <tr>
  <xsl:choose>
   <xsl:when test="position() = 1">
    <xsl:call-template name="src_string">
     <xsl:with-param name="rows" select="$rows"/>
     <xsl:with-param name="s"    select="../@s"/>
    </xsl:call-template>
    <xsl:call-template name="hdr_string">
     <xsl:with-param name="hdr_name" select="'cloudOpacityLvl'"/>
     <xsl:with-param name="rows"     select="$rows"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
  <td nowrap="1" colspan="2">
   <xsl:value-of select="concat(oktas/@v, '/8')"/>
   <xsl:if test="boolean(weather)">
    <xsl:text> </xsl:text>
    <xsl:for-each select="weather">
     <xsl:call-template name="printWeather"/>
    </xsl:for-each>
   </xsl:if>
   <xsl:if test="boolean(cloudType)">
    <xsl:value-of select="concat(' ', $trans/cloudType[@o=current()/cloudType/@v])"/>
   </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypeLvl">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'cloud'"/>
  </xsl:call-template>
  <xsl:choose>
   <xsl:when test="boolean(cloudBase)">
    <td nowrap="1">
    <xsl:value-of select="$trans/cloudType[@o=current()/cloudType/@v]"/>
    <xsl:value-of select="concat(' ', $trans/t[@o='cloud-at'], ' ')"/>
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'FT'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'M'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/cloudType[@o=current()/cloudType/@v]"/>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTrace">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'tracesOf'"/>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:if test="boolean(isLower)">
   <xsl:value-of select="concat($trans/t[@o='isLower'], ' ')"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeNotAvailable)">
   <xsl:value-of select="$trans/t[@o='cloudTypeNotAvailable']"/>
  </xsl:if>
  <xsl:for-each select="cloudType">
   <xsl:if test="position() != 1"><xsl:text>, </xsl:text></xsl:if>
   <xsl:value-of select="$trans/cloudType[@o=current()/@v]"/>
  </xsl:for-each>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="seaCondition|swellCondition">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="notAvailable"/>
  <xsl:if test="boolean(seaCondVal)">
   <xsl:value-of select="$trans/seaCondition[@o=current()/seaCondVal/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(swellCondVal)">
   <xsl:value-of select="$trans/swellCondition[@o=current()/swellCondVal/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(locationAnd)">
   <xsl:text>,</xsl:text>
   <xsl:apply-templates select="locationAnd">
    <xsl:with-param name="locOrDir" select="'compassDirFrom'"/>
   </xsl:apply-templates>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obscuration">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='obscuration'], '|')"/>
  <xsl:for-each select="weather">
   <xsl:call-template name="printWeather"/>
  </xsl:for-each>
  <xsl:if test="boolean(cloudPhenom)">
   <xsl:value-of select="$trans/cloudPhenom[@o=current()/cloudPhenom/@v]"/>
  </xsl:if>
  <xsl:value-of select="substring-after($trans/hdr[@o='obscuration'], '|')"/>
  </td>
  <xsl:for-each select="cloud">
   <xsl:call-template name="printCloud">
    <xsl:with-param name="at_abv" select="'cloud-at'"/>
   </xsl:call-template>
  </xsl:for-each>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="variableCeiling">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='variable-from'], ' ', cloudBaseFrom/@v, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(cloudBaseFrom/@v div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='variable-to'], ' ', cloudBaseTo/@v, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(cloudBaseTo/@v div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="pressureChange">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:apply-templates select="period">
   <xsl:with-param name="pre" select="' '"/>
   <xsl:with-param name="header" select="$trans/hdr[@o='pressureChange']"/>
  </xsl:apply-templates>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable|invalidFormat)">
    <xsl:apply-templates select="notAvailable|invalidFormat"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="sign">
     <xsl:if test="pressureChangeVal/@v &gt; 0">+</xsl:if>
    </xsl:variable>
    <xsl:value-of select="concat($sign, pressureChangeVal/@v, $trans/units[@o='hPa'])"/>
    <xsl:if test="boolean(pressureTendency)">
     <xsl:value-of select="concat(', ', $trans/pressureTend[@o=current()/pressureTendency/@v])"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="ceilVisVariable">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string"/>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibilityFrom"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'to'"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibilityTo"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="rwySfcCondition">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:for-each select="*">
   <xsl:if test="name() = 'notAvailable'">
    <xsl:value-of select="$trans/t[@o='decelerometerReadingNA']"/>
   </xsl:if>
   <xsl:if test="name() = 'decelerometer'">
    <xsl:value-of select="concat($trans/t[@o='decelerometerReading'], ' ',@v)"/>
   </xsl:if>
   <xsl:if test="name() = 'rwySfc'">
    <xsl:value-of select="$trans/rwySfc[@o=current()/@v]"/>
   </xsl:if>
   <xsl:if test="position() != last()">
    <xsl:text>, </xsl:text>
   </xsl:if>
  </xsl:for-each>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="rainfall">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(rainfall10min/@v, $trans/t[@o='rainfall10min'], rainfall0900/@v, $trans/t[@o='rainfall0900'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="NEFO_PLAYA">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <xsl:choose>
   <xsl:when test="boolean(SKC)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/cloudCover[@o='SKC']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'FT'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'M'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
    </xsl:call-template>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="densityAlt|pressureAlt">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1">
  <xsl:value-of select="concat(altitude/@v, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(altitude/@v div 10 * $FT2M, '0.0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="VISNO|CHINO">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:variable name="s" select="$trans/t[@o=name(current())]"/>
  <xsl:variable name="p" select="$trans/t[@o='rwyDesig']"/>
  <xsl:value-of select="substring-before($s, '|')"/>
  <xsl:value-of select="substring-before($p, '|')"/>
  <xsl:value-of select="rwyDesig/@v"/>
  <xsl:value-of select="substring-after($p, '|')"/>
  <xsl:value-of select="substring-after($s, '|')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsTimeOffset">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(minutes/@v, ' ', $trans/t[@o='minutes'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="waterEquivOfSnow">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='waterEquivOfSnow'], '|')"/>
  <xsl:choose>
   <xsl:when test="boolean(period)">
    <xsl:apply-templates select="period">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='onGround']"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='waterEquivOfSnow'], '|')"/>
  </td>
  <xsl:call-template name="precipAmountVal"/>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="snowCover">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/snowCoverType[@o=current()/snowCoverType/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="climate">
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='temp1']"/>
   <xsl:with-param name="rows">
    <xsl:choose>
     <xsl:when test="boolean(precipAmount2Inch|precipAmount2MM)">4</xsl:when>
     <xsl:when test="boolean(precipAmount1Inch|precipAmount1MM|traces)">3</xsl:when>
     <xsl:otherwise>2</xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="temp1"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='temp2']"/>
   <xsl:with-param name="temp" select="temp2"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(precipAmount1Inch|precipAmount1MM|traces)">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'precipAmount1'"/>
   </xsl:call-template>
   <xsl:choose>
    <xsl:when test="boolean(precipAmount1Inch)">
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount1Inch/@v * ($FT2M div 12 * 1000), '0'), $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount1Inch/@v, $trans/units[@o='IN'])"/>
     </td>
    </xsl:when>
    <xsl:when test="boolean(precipAmount1MM)">
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount1MM/@v, $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount1MM/@v div ($FT2M div 12 * 1000), '0.00'), $trans/units[@o='IN'])"/>
     </td>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='traces']"/>
     </td>
    </xsl:otherwise>
   </xsl:choose>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(precipAmount2Inch|precipAmount2MM)">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'precipAmount2'"/>
   </xsl:call-template>
   <xsl:choose>
    <xsl:when test="boolean(precipAmount2Inch)">
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount2Inch/@v * ($FT2M div 12 * 1000), '0'), $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount2Inch/@v, $trans/units[@o='IN'])"/>
     </td>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount2MM/@v, $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount2MM/@v div ($FT2M div 12 * 1000), '0.00'), $trans/units[@o='IN'])"/>
     </td>
    </xsl:otherwise>
   </xsl:choose>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tornadicActivity">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <dl style="margin: 0;"><dt>
  <xsl:value-of select="$trans/tornadicActivity[@o=current()/tornadicActivityType/@v]"/>
  <xsl:if test="boolean(locationAnd)">
   <xsl:apply-templates select="locationAnd">
    <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
   </xsl:apply-templates>
   <xsl:if test="boolean(MOV|MOVD|isStationary)">
    <xsl:text>,</xsl:text>
   </xsl:if>
  </xsl:if>
  <xsl:apply-templates select="MOV|MOVD|isStationary"/>
  <xsl:text>:</xsl:text></dt>
  <xsl:apply-templates select="beganAt|endedAt"/>
  </dl></td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="balloon">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:if test="boolean(disappearedAt)">
   <xsl:value-of select="substring-before($trans/t[@o='balloonDisapp'], '|')"/>
   <xsl:value-of select="concat(disappearedAt/distance/@v, $trans/units[@o=current()/disappearedAt/distance/@u])"/>
   <xsl:value-of select="substring-after($trans/t[@o='balloonDisapp'], '|')"/>
  </xsl:if>
  <xsl:if test="boolean(visibleTo)">
   <xsl:value-of select="substring-before($trans/t[@o='balloonVisib'], '|')"/>
   <xsl:value-of select="concat(visibleTo/distance/@v, $trans/units[@o=current()/visibleTo/distance/@u])"/>
   <xsl:value-of select="substring-after($trans/t[@o='balloonVisib'], '|')"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="firstObs|nextObs|lastObs">
  <xsl:variable name="name" select="name()"/>
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="substring-before($trans/t[@o=$name], '|')"/>
  <xsl:apply-templates select="isManned|isStaffed"/>
  <xsl:value-of select="substring-after($trans/t[@o=$name], '|')"/>
  <xsl:apply-templates select="timeAt">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="notAvailable|isStaffed|isManned|isStationary|coverNotCont|noMeasurement|traces|oktasNotAvailable">
  <xsl:value-of select="$trans/t[@o=name(current())]"/>
 </xsl:template>

 <xsl:template match="skyObscured">
  <xsl:value-of select="$trans/phenomenon[@o='SKY_OBSC']"/>
 </xsl:template>

 <xsl:template match="estimated">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:for-each select="estimatedItem">
   <xsl:if test="position() != 1"><xsl:text>, </xsl:text></xsl:if>
   <xsl:value-of select="$trans/estimatedItem[@o=current()/@v]"/>
  </xsl:for-each>
  <xsl:value-of select="concat(' ', $trans/t[@o='estimated'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="RSNK|LAG_PK">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:choose>
     <xsl:when test="boolean(wind/gustSpeed) and boolean(dewpoint)">5</xsl:when>
     <xsl:when test="boolean(wind/gustSpeed|dewpoint)">4</xsl:when>
     <xsl:otherwise>3</xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
  </xsl:call-template>
  <td nowrap="1" colspan="3">
  <b><xsl:value-of select="$trans/hdr[@o=name(current())]"/></b>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-temp']"/>
   <xsl:with-param name="temp" select="air"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(dewpoint)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-dew']"/>
    <xsl:with-param name="temp" select="dewpoint"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='sfcWind']"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="RADAT">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:choose>
     <xsl:when test="boolean(isMissing)">2</xsl:when>
     <xsl:otherwise>3</xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
  </xsl:call-template>
  <td nowrap="1" colspan="3">
  <b><xsl:value-of select="$trans/hdr[@o='RADAT']"/></b>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:choose>
   <xsl:when test="boolean(isMissing)">
    <tr>
    <td nowrap="1" colspan="3">
    <xsl:value-of select="$trans/t[@o='isMissing']"/>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <tr>
    <xsl:call-template name="hdr_string">
     <xsl:with-param name="hdr_name" select="'relHumid'"/>
    </xsl:call-template>
    <td nowrap="1" colspan="2">
    <xsl:value-of select="relHumid/@v"/>
    <xsl:text>%</xsl:text>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
    <tr>
    <xsl:call-template name="hdr_string">
     <xsl:with-param name="hdr_name" select="'freezingLvl'"/>
    </xsl:call-template>
    <td nowrap="1">
    <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' ', distance/@v, $trans/units[@o='FT'])"/>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:value-of select="concat(format-number(distance/@v div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="radiationSun">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:apply-templates select="rad0PosNet|rad1NegNet|rad2GlobalSolar|rad3DiffusedSolar|rad4DownwardLongWave|rad5UpwardLongWave|rad6ShortWave" mode="count" />
   </xsl:with-param>
  </xsl:call-template>
  <td nowrap="1">
  <xsl:apply-templates select="sunshinePeriod">
   <xsl:with-param name="pre" select="' '"/>
   <xsl:with-param name="header" select="$trans/hdr[@o='sunshine']"/>
  </xsl:apply-templates>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(sunshine)">
    <xsl:variable name="sunshineMinutes">
     <xsl:if test="sunshine/@u = 'MIN'">
      <xsl:value-of select="sunshine/@v" />
     </xsl:if>
     <xsl:if test="sunshine/@u = 'H'">
      <xsl:value-of select="format-number(sunshine/@v * 60, '0')" />
     </xsl:if>
    </xsl:variable>
    <xsl:choose>
     <xsl:when test="$sunshineMinutes &gt; 59">
      <xsl:variable name="min" select="$sunshineMinutes mod 60"/>
      <xsl:value-of select="concat(($sunshineMinutes - $min) div 60, $trans/units[@o='H'])"/>
      <xsl:if test="$min &gt; 0">
       <xsl:value-of select="concat(' ', $min, $trans/units[@o='MIN'])"/>
      </xsl:if>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="concat($sunshineMinutes, $trans/units[@o='MIN'])"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="rad0PosNet|rad1NegNet|rad2GlobalSolar|rad3DiffusedSolar|rad4DownwardLongWave|rad5UpwardLongWave|rad6ShortWave"/>
 </xsl:template>

 <xsl:template match="radiationSun/*" mode="count">
  <xsl:if test="position() = 1">
   <xsl:value-of select="last() + 1"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="rad0PosNet|rad1NegNet|rad2GlobalSolar|rad3DiffusedSolar|rad4DownwardLongWave|rad5UpwardLongWave|rad6ShortWave|radShortWave|radDirectSolar">
  <tr>
  <xsl:if test="@s != ''">
   <xsl:call-template name="src_string"/>
  </xsl:if>
  <td nowrap="1">
  <xsl:apply-templates select="../radiationPeriod|radiationPeriod">
   <xsl:with-param name="pre" select="' '"/>
   <xsl:with-param name="header" select="$trans/hdr[@o=name(current())]"/>
  </xsl:apply-templates>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(radiationValue/@v, $trans/units[@o=current()/radiationValue/@u])"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="hailStones|glazeDeposit|rimeDeposit|compoundDeposit|wetsnowDeposit">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td colspan="2">
  <xsl:value-of select="$trans/t[@o='diameter']"/>
  <xsl:apply-templates select="notAvailable"/>
  <xsl:if test="boolean(traces)">
   <xsl:value-of select="$trans/t[@o='notMeasurable']"/>
  </xsl:if>
  <xsl:if test="boolean(diameter)">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="diameter"/>
   </xsl:call-template>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="activeRwy">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td colspan="2">
  <xsl:value-of select="$trans/t[@o='activeRwy']"/>
  <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="transitionLvl">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' FL ', level/@v)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="QBB|QBJ">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(altitude/@v, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="currentATIS">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="ATIS/@v"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="notRecognised|obsInitials">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td colspan="2">
  <xsl:value-of select="@s"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="fcstNotAvbl">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/fcstNotAvblReason[@o=current()/fcstNotAvblReason/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="stateOfGround">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="notAvailable"/>
  <xsl:if test="boolean(stateOfGroundVal)">
   <xsl:value-of select="$trans/stateOfGround[@o=current()/stateOfGroundVal/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="stateOfGroundSnow">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="notAvailable"/>
  <xsl:if test="boolean(stateOfGroundSnowVal)">
   <xsl:value-of select="$trans/stateOfGroundSnow[@o=current()/stateOfGroundSnowVal/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="snowDepth|snowFall">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:variable name="hdr" select="$trans/hdr[@o=name(current())]"/>
  <xsl:value-of select="substring-before($hdr, '|')"/>
  <xsl:apply-templates select="period|timeBeforeObsSince|timeSince">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  <xsl:value-of select="substring-after($hdr, '|')"/>
  </td>
  <xsl:call-template name="precipAmountVal"/>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypesDrift">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="3"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="3"/>
  </xsl:call-template>
  <xsl:text>&#10;&#9;</xsl:text>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/t[@o='low']"/>
  <xsl:if test="boolean(cloudTypeLowNA)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeLowNone)">
   <xsl:value-of select="$trans/t[@o='cloudNone']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeLowInvisible)">
   <xsl:value-of select="$trans/t[@o='cloudInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeLowDir)">
   <xsl:value-of select="$trans/compassDir[@o=current()/cloudTypeLowDir/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td nowrap="1" colspan="2">
  <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='middle']"/>
  <xsl:if test="boolean(cloudTypeMiddleNA)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeMiddleNone)">
   <xsl:value-of select="$trans/t[@o='cloudNone']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeMiddleInvisible)">
   <xsl:value-of select="$trans/t[@o='cloudInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeMiddleDir)">
   <xsl:value-of select="$trans/compassDir[@o=current()/cloudTypeMiddleDir/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td nowrap="1" colspan="2">
  <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='high']"/>
  <xsl:if test="boolean(cloudTypeHighNA)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeHighNone)">
   <xsl:value-of select="$trans/t[@o='cloudNone']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeHighInvisible)">
   <xsl:value-of select="$trans/t[@o='cloudInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeHighDir)">
   <xsl:value-of select="$trans/compassDir[@o=current()/cloudTypeHighDir/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudLocation">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:if test="boolean(cloudTypeNotAvailable)">
   <xsl:value-of select="$trans/t[@o='cloudTypeNotAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudType)">
   <xsl:value-of select="$trans/cloudType[@o=current()/cloudType/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(cloudNone)">
   <xsl:value-of select="concat(', ', $trans/t[@o='cloudNone'])"/>
  </xsl:if>
  <xsl:if test="boolean(cloudInvisible)">
   <xsl:value-of select="concat(', ', $trans/t[@o='cloudInvisible'])"/>
  </xsl:if>
  <xsl:apply-templates select="cloudDir">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  <xsl:text>, </xsl:text>
  <xsl:if test="boolean(topsInvisible)">
   <xsl:value-of select="$trans/t[@o='topsInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(elevationAngle)">
   <xsl:value-of select="$trans/t[@o='elevationAngle']"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="elevationAngle"/>
   </xsl:call-template>
   <xsl:text>°</xsl:text>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="group5xxxxNA">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="evapo">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <td nowrap="1">
  <xsl:apply-templates select="period">
   <xsl:with-param name="pre" select="' '"/>
   <xsl:with-param name="header">
    <xsl:choose>
     <xsl:when test="evapoIndicator/@v &lt; 5">
      <xsl:value-of select="$trans/hdr[@o='evaporation']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$trans/hdr[@o='evapotranspiration']"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
  </xsl:apply-templates>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(evapoAmount/@v, $trans/units[@o='MM'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name">
    <xsl:choose>
     <xsl:when test="evapoIndicator/@v &lt; 5">evapoInstrumentation</xsl:when>
     <xsl:otherwise>cropEvapotranspiration</xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/evapoIndicator[@o=current()/evapoIndicator/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="tempChange">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='tempChange'], '|')"/>
  <xsl:call-template name="printHoursFromTill">
   <xsl:with-param name="hoursStr" select="$trans/t[@o='sinceHours']"/>
  </xsl:call-template>
  <xsl:value-of select="substring-after($trans/hdr[@o='tempChange'], '|')"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat(temp/@v, ' °C')"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(temp/@v div 1.8, '0.#'), ' °F')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudInfo">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:if test="boolean(cloudBaseFrom|visVertFrom)">2</xsl:if>
   </xsl:with-param>
  </xsl:call-template>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="boolean(cloudBaseNotAvailable|cloudBase|cloudBaseFrom)">
    <xsl:variable name="hdr" select="$trans/hdr[@o='cloudInfoBase']"/>
    <xsl:value-of select="substring-before($hdr, '|')"/>
    <xsl:for-each select="cloudOktas">
     <xsl:call-template name="cloudOktas"/>
    </xsl:for-each>
    <xsl:text> </xsl:text>
    <xsl:choose>
     <xsl:when test="boolean(cloudTypeNotAvailable)">
      <xsl:value-of select="$trans/t[@o='cloudTypeNotAvailable']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$trans/cloudType[@o=current()/cloudType/@v]"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="boolean(cloudBaseFrom)">
     <xsl:value-of select="concat(' ', $trans/t[@o='level-from'])"/>
    </xsl:if>
    <xsl:value-of select="substring-after($hdr, '|')"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/hdr[@o='visVert']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  <xsl:if test="boolean(cloudBaseNotAvailable)">
   <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </td>
  </xsl:if>
  <xsl:if test="boolean(cloudBase)">
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBase"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBase"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
  </xsl:if>
  <xsl:if test="boolean(cloudBaseFrom)">
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseFrom"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseFrom"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
  </xsl:if>
  <xsl:if test="boolean(visVert)">
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="visVert"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="boolean(visVertFrom)">
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="visVertFrom"/>
   </xsl:call-template>
  </xsl:if>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(cloudBaseFrom)">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'to'"/>
   </xsl:call-template>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseTo"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseTo"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(visVertTo)">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'to'"/>
   </xsl:call-template>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="visVertTo"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="cloudEvolution">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:apply-templates select="maxConcentration" mode="count">
     <xsl:with-param name="offset" select="1"/>
    </xsl:apply-templates>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="cloudType"/>
  <xsl:value-of select="concat(': ', $trans/cloudEvol[@o=current()/cloudEvol/@v])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="maxConcentration"/>
 </xsl:template>

 <xsl:template match="cloudTopsHeight">
  <xsl:variable name="offset">
   <xsl:choose>
    <xsl:when test="boolean(cloudTopsFrom)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:choose>
     <xsl:when test="boolean(maxConcentration)">
      <xsl:apply-templates select="maxConcentration" mode="count">
       <xsl:with-param name="offset" select="$offset"/>
      </xsl:apply-templates>
     </xsl:when>
     <xsl:when test="$offset != 1"><xsl:value-of select="$offset"/></xsl:when>
    </xsl:choose>
   </xsl:with-param>
  </xsl:call-template>
  <td nowrap="1">
  <xsl:variable name="hdr" select="$trans/hdr[@o='cloudTopsHeight']"/>
  <xsl:value-of select="substring-before($hdr, '|')"/>
  <xsl:if test="boolean(cloudTopsFrom)">
   <xsl:value-of select="concat(' ', $trans/t[@o='level-from'])"/>
  </xsl:if>
  <xsl:value-of select="substring-after($hdr, '|')"/>
  </td>
  <xsl:if test="boolean(notAvailable)">
   <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </td>
  </xsl:if>
  <xsl:if test="boolean(cloudTops)">
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudTops"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudTops"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
  </xsl:if>
  <xsl:if test="boolean(cloudTopsFrom)">
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudTopsFrom"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudTopsFrom"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
  </xsl:if>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(cloudTopsFrom)">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'to'"/>
   </xsl:call-template>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudTopsTo"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudTopsTo"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:apply-templates select="maxConcentration"/>
 </xsl:template>

 <xsl:template name="cloudOktas">
  <xsl:choose>
   <xsl:when test="boolean(oktasNotAvailable|skyObscured)">
    <xsl:apply-templates select="oktasNotAvailable|skyObscured"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(oktas/@v, '/8')"/>
    <xsl:if test="oktas/@v = 1">
     <xsl:value-of select="$trans/t[@o='lessOktas']"/>
    </xsl:if>
    <xsl:if test="oktas/@v = 7">
     <xsl:value-of select="$trans/t[@o='moreOktas']"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="precipCharacter">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(noPrecip)">
    <xsl:value-of select="$trans/t[@o='noPrecip']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="phenomDescr|phenomDescr2"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="beginPrecip|endPrecip">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(noPrecip)">
    <xsl:value-of select="$trans/t[@o='noPrecip']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="printHoursFromTill">
     <xsl:with-param name="hoursStr" select="$trans/t[@o='hoursAgo']"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="weatherSynopInfo">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name">
    <xsl:choose>
     <xsl:when test="boolean(timeBeforeObsBegin)">weatherSynopBegin</xsl:when>
     <xsl:when test="boolean(timeBeforeObsEnd)">weatherSynopEnd</xsl:when>
     <xsl:when test="boolean(timeBeforeObsSince)">weatherSynopSince</xsl:when>
     <xsl:otherwise>weatherSynopCharacter</xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
  </xsl:call-template>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="phenomVariation|location|phenomDescr|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="timeBeforeObs|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
  <xsl:param name="pre"/>
  <xsl:if test="position() = 1"><xsl:value-of select="$pre"/></xsl:if>
  <xsl:if test="position() != 1"><xsl:text>, </xsl:text></xsl:if>
  <xsl:choose>
   <xsl:when test="boolean(hoursUnknown)">
    <xsl:variable name="name" select="concat(name(), 'NA')"/>
    <xsl:value-of select="$trans/t[@o=$name]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="printHoursFromTill">
     <xsl:with-param name="hoursStr">
      <xsl:choose>
       <xsl:when test="name() = 'timeBeforeObsBegin'">
        <xsl:value-of select="$trans/t[@o='beganAgo']"/>
       </xsl:when>
       <xsl:when test="name() = 'timeBeforeObsEnd'">
        <xsl:value-of select="$trans/t[@o='endedAgo']"/>
       </xsl:when>
       <xsl:when test="name() = 'timeBeforeObsSince'">
        <xsl:value-of select="$trans/t[@o='sinceHours']"/>
       </xsl:when>
       <xsl:otherwise>
        <xsl:value-of select="$trans/t[@o='hoursAgo']"/>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printHoursFromTill">
  <xsl:param name="hoursStr"/>
  <xsl:value-of select="substring-before($hoursStr, '|')"/>
  <xsl:if test="hoursFrom/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:value-of select="hoursFrom/@v"/>
  <xsl:if test="boolean(hoursTill)">
   <xsl:if test="boolean(hoursFrom)"> - </xsl:if>
   <xsl:if test="hoursTill/@q = 'isLess'">&lt;</xsl:if>
   <xsl:value-of select="hoursTill/@v"/>
  </xsl:if>
  <xsl:value-of select="substring-after($hoursStr, '|')"/>
 </xsl:template>

 <xsl:template match="highestGust|highestMeanSpeed|meanSpeed|lowestMeanSpeed|highestWind">
  <xsl:variable name="hdr2" select="$trans/hdr[@o=name(current())]"/>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr">
    <xsl:value-of select="substring-before($hdr2, '|')"/>
    <xsl:apply-templates select="measurePeriod"/>
    <xsl:apply-templates select="timeAt">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="period|timeBeforeObs|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
     <xsl:with-param name="pre" select="' '"/>
    </xsl:apply-templates>
    <xsl:value-of select="substring-after($hdr2, '|')"/>
   </xsl:with-param>
   <xsl:with-param name="s" select="@s"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="precipPeriods">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td colspan="2">
  <xsl:call-template name="printHoursFromTill">
   <xsl:with-param name="hoursStr" select="concat('|', $trans/units[@o='H'])"/>
  </xsl:call-template>
  <xsl:choose>
   <xsl:when test="boolean(periodsNA)">
    <xsl:value-of select="$trans/t[@o='periodNotAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(onePeriod)">
    <xsl:value-of select="$trans/t[@o='onePeriod']"/>
   </xsl:when>
   <xsl:when test="boolean(morePeriods)">
    <xsl:value-of select="$trans/t[@o='morePeriods']"/>
   </xsl:when>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="stateOfSky">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td colspan="2">
  <xsl:apply-templates select="notAvailable"/>
  <xsl:if test="boolean(stateOfSkyVal)">
   <xsl:value-of select="$trans/stateOfSky[@o=current()/stateOfSkyVal/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudBelowStation">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <td nowrap="1" rowspan="2">
  <xsl:variable name="hdr" select="$trans/hdr[@o='cloudBelowStation']"/>
  <xsl:value-of select="substring-before($hdr, '|')"/>
  <xsl:for-each select="cloudOktas">
   <xsl:call-template name="cloudOktas"/>
  </xsl:for-each>
  <xsl:value-of select="concat(' ', $trans/cloudType[@o=current()/cloudType/@v])"/>
  <xsl:value-of select="substring-after($hdr, '|')"/>
  </td>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudTops"/>
   <xsl:with-param name="unit" select="'M'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
  </xsl:call-template>
  </td>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudTops"/>
   <xsl:with-param name="unit" select="'FT'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
  </xsl:call-template>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td colspan="2">
  <xsl:value-of select="$trans/cloudTopDescr[@o=current()/cloudTopDescr/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="windDir">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='windDir'], '|')"/>
  <xsl:apply-templates select="period">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  <xsl:value-of select="substring-after($trans/hdr[@o='windDir'], '|')"/>
  </td>
  <td colspan="2">
  <xsl:apply-templates select="compassDir"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="recordTemp|recordTempCity">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="substring-before($trans/t[@o=name(current())], '|')"/>
  <xsl:if test="recordType/@v = 'HI'">
   <xsl:value-of select="$trans/t[@o='highest']"/>
  </xsl:if>
  <xsl:if test="recordType/@v = 'LO'">
   <xsl:value-of select="$trans/t[@o='lowest']"/>
  </xsl:if>
  <xsl:value-of select="substring-after($trans/t[@o=name(current())], '|')"/>
  <xsl:choose>
   <xsl:when test="(recordType/@v = 'HI' and recordPeriod/@v = 'SE') or (recordType/@v = 'LO' and recordPeriod/@v = 'SL')">
    <xsl:value-of select="$trans/recordPeriod[@o='spring']"/>
   </xsl:when>
   <xsl:when test="(recordType/@v = 'HI' and recordPeriod/@v = 'SL') or (recordType/@v = 'LO' and recordPeriod/@v = 'SE')">
    <xsl:value-of select="$trans/recordPeriod[@o='fall']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/recordPeriod[@o=current()/recordPeriod/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:choose>
   <xsl:when test="not(boolean(recordType/@q))">
    <xsl:value-of select="$trans/t[@o='isEqualled']"/>
   </xsl:when>
   <xsl:when test="recordType/@v = 'HI'">
    <xsl:value-of select="$trans/t[@o='isOverrun']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='isUnderrun']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="tideData">
  <xsl:variable name="rows">
   <xsl:if test="not(boolean(notAvailable))">2</xsl:if>
  </xsl:variable>
  <xsl:variable name="sign">
   <xsl:if test="tideDeviation/@v &gt; 0">+</xsl:if>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/tideType[@o=current()/tideType/@v]"/>
    <xsl:value-of select="$trans/tideLevel[@o=current()/tideLevel/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="$rows = 2">
   <tr>
   <xsl:call-template name="hdr_string">
    <xsl:with-param name="hdr_name" select="'tideDeviation'"/>
   </xsl:call-template>
   <td nowrap="1">
   <xsl:value-of select="$sign"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="tideDeviation"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:value-of select="$sign"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="tideDeviation"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="1"/>
    <xsl:with-param name="format" select="'0'"/>
   </xsl:call-template>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="verticalClouds">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:apply-templates select="maxConcentration" mode="count">
     <xsl:with-param name="offset" select="1"/>
    </xsl:apply-templates>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="hdr_string"/>
  <td colspan="2">
  <xsl:value-of select="concat($trans/t[@o=current()/phenomDescr/@v], ' ', $trans/cloudTypeVertical[@o=current()/cloudTypeVertical/@v])"/>
  <xsl:apply-templates select="location">
   <xsl:with-param name="locOrDirBefore" select="substring-before($trans/t[@o='compassDirLocation'], '|')"/>
   <xsl:with-param name="locOrDirAfter" select="substring-after($trans/t[@o='compassDirLocation'], '|')"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="maxConcentration"/>
 </xsl:template>

 <xsl:template match="specialClouds|orographicClouds">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows">
    <xsl:apply-templates select="maxConcentration" mode="count">
     <xsl:with-param name="offset" select="1"/>
    </xsl:apply-templates>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="name() = 'specialClouds'">
    <xsl:value-of select="$trans/cloudTypeSpecial[@o=current()/cloudTypeSpecial/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/cloudTypeOrographic[@o=current()/cloudTypeOrographic/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:apply-templates select="location">
   <xsl:with-param name="locOrDirBefore" select="substring-before($trans/t[@o='compassDirLocation'], '|')"/>
   <xsl:with-param name="locOrDirAfter" select="substring-after($trans/t[@o='compassDirLocation'], '|')"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="maxConcentration"/>
 </xsl:template>

 <xsl:template match="maxConcentration" mode="count">
  <xsl:param name="offset"/>
  <xsl:if test="position() = 1 and last() + $offset != 1">
   <xsl:value-of select="last() + $offset"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="maxConcentration|maxCloudLocation|maxLowCloudLocation|maxWeatherLocation">
  <tr>
  <xsl:if test="name() != 'maxConcentration'">
   <xsl:call-template name="src_string"/>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='maxConcentration'], '|')"/>
  <xsl:choose>
   <xsl:when test="name() = 'maxLowCloudLocation'">
    <xsl:value-of select="$trans/concentrationPhenom[@o='lowCloud']"/>
   </xsl:when>
   <xsl:when test="name() = 'maxWeatherLocation'">
    <xsl:value-of select="$trans/concentrationPhenom[@o=current()/weatherType/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/concentrationPhenom[@o='cloud']"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='maxConcentration'], '|')"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:if test="boolean(cloudType)">
   <xsl:value-of select="$trans/cloudType[@o=current()/cloudType/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeLow)">
   <xsl:value-of select="$trans/cloudTypeLow[@o=current()/cloudTypeLow/@v]"/>
  </xsl:if>
  <xsl:apply-templates select="location">
   <xsl:with-param name="locOrDirBefore" select="substring-before($trans/t[@o='compassDirLocation'], '|')"/>
   <xsl:with-param name="locOrDirAfter" select="substring-after($trans/t[@o='compassDirLocation'], '|')"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(elevAboveHorizon)">
   <xsl:value-of select="concat(', ', $trans/elevAboveHorizon[@o=current()/elevAboveHorizon/@v])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="opticalPhenom">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat($trans/opticalPhenomenon[@o=current()/opticalPhenomenon/@v], ', ', $trans/t[@o=current()/phenomDescr/@v], ' ', $trans/t[@o='intensity'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="equivWindSpeed">
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr">
    <xsl:value-of select="substring-before($trans/hdr[@o='equivWindSpeed'], '|')"/>
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="elevation"/>
    </xsl:call-template>
    <xsl:value-of select="substring-after($trans/hdr[@o='equivWindSpeed'], '|')"/>
   </xsl:with-param>
   <xsl:with-param name="s" select="@s"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="displacement">
  <tr>
  <xsl:call-template name="src_string"/>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='displacement'], '|')"/>
  <xsl:apply-templates select="period">
   <xsl:with-param name="pre" select="' '"/>
  </xsl:apply-templates>
  <xsl:value-of select="substring-after($trans/hdr[@o='displacement'], '|')"/>
  </td>
  <xsl:apply-templates select="speed" mode="range">
   <xsl:with-param name="hdr">
    <xsl:choose>
     <xsl:when test="boolean(dirNotAvailable)">
      <xsl:value-of select="concat($trans/t[@o='dirNotAvailable'], ' ')"/>
     </xsl:when>
     <xsl:when test="boolean(isStationary)">
      <xsl:value-of select="concat($trans/t[@o='isStationary'], ', ')"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="substring-before($trans/t[@o='compassDirTo'], '|')"/>
      <xsl:value-of select="substring-before($trans/t[@o='compassDirDescr'], '|')"/>
      <xsl:apply-templates select="compassDir"/>
      <xsl:value-of select="substring-after($trans/t[@o='compassDirDescr'], '|')"/>
      <xsl:value-of select="substring-after($trans/t[@o='compassDirTo'], '|')"/>
      <xsl:text>, </xsl:text>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:with-param>
  </xsl:apply-templates>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="speed" mode="range">
  <xsl:param name="hdr"/>
  <td nowrap="1">
  <xsl:if test="position() = 1"><xsl:value-of select="$hdr"/></xsl:if>
  <xsl:if test="position() != 1"><xsl:value-of select="'&#9;&#9;'"/></xsl:if>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="range" select="1"/>
   <xsl:with-param name="val" select="."/>
  </xsl:call-template>
  </td>
 </xsl:template>

 <xsl:template match="seaSurfaceTemp|wetbulbTemperature">
  <xsl:variable name="rows">
   <xsl:if test="not(boolean(notAvailable))">2</xsl:if>
  </xsl:variable>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o=name(current())]"/>
   <xsl:with-param name="rows" select="$rows"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="$rows = 2">
   <tr>
   <td nowrap="1">
   <xsl:value-of select="$trans/t[@o='typeOfMeasurement']"/>
   </td>
   <td colspan="2">
   <xsl:if test="boolean(waterTempMeasurement)">
    <xsl:value-of select="$trans/waterTempMeasurement[@o=current()/waterTempMeasurement/@v]"/>
   </xsl:if>
   <xsl:if test="boolean(wetbulbTempMeasurement)">
    <xsl:value-of select="$trans/wetbulbTempMeasurement[@o=current()/wetbulbTempMeasurement/@v]"/>
   </xsl:if>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="waveDataInstrumental|waveData">
  <tr>
  <xsl:call-template name="src_string"/>
  <xsl:call-template name="hdr_string"/>
  <td colspan="2">
  <xsl:if test="not(boolean(isCalm|period|height))">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(isCalm)">
   <xsl:value-of select="$trans/t[@o='calmSea']"/>
  </xsl:if>
  <xsl:if test="boolean(period)">
   <xsl:value-of select="concat($trans/t[@o='period'], ': ')"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="period"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="boolean(height)">
   <xsl:if test="boolean(period)">, </xsl:if>
   <xsl:value-of select="concat($trans/t[@o='height'], ': ')"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="range" select="1"/>
    <xsl:with-param name="val" select="height"/>
   </xsl:call-template>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="swellData">
  <xsl:variable name="rows">
   <xsl:if test="boolean(swell1Data) and boolean(swell2Data)">2</xsl:if>
  </xsl:variable>
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:apply-templates select="swell1Data"/>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="$rows = 2">
   <tr>
   <xsl:apply-templates select="swell2Data"/>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="swell1Data|swell2Data">
  <td colspan="2">
  <xsl:if test="not(boolean(dir|period|height))">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(dir)">
   <xsl:value-of select="concat($trans/t[@o='wind-from'], ' ', $trans/compassDir16/arr[1+format-number(current()/dir/@v div 45 * 2, '0')], ' (', dir/@v, '°', ' (+', dir/@rp, '°/-', dir/@rn, '°)), ')"/>
  </xsl:if>
  <xsl:if test="boolean(period)">
   <xsl:value-of select="concat($trans/t[@o='period'], ': ')"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="period"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="boolean(height)">
   <xsl:if test="boolean(period)">, </xsl:if>
   <xsl:value-of select="concat($trans/t[@o='height'], ': ')"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="range" select="1"/>
    <xsl:with-param name="val" select="height"/>
   </xsl:call-template>
  </xsl:if>
  </td>
 </xsl:template>

 <xsl:template match="snowCoverCharReg">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'snowCoverCharacter'"/>
  </xsl:call-template>
  <td colspan="2">
  <xsl:value-of select="$trans/snowCoverCharacter[@o=current()/snowCoverCharacter/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'snowCoverRegularity'"/>
  </xsl:call-template>
  <td colspan="2">
  <xsl:value-of select="$trans/snowCoverRegularity[@o=current()/snowCoverRegularity/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="driftSnow">
  <tr>
  <xsl:call-template name="src_string">
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'driftSnowData'"/>
  </xsl:call-template>
  <td colspan="2">
  <xsl:value-of select="$trans/driftSnowData[@o=current()/driftSnowData/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="hdr_string">
   <xsl:with-param name="hdr_name" select="'driftSnowEvolution'"/>
  </xsl:call-template>
  <td colspan="2">
  <xsl:value-of select="$trans/driftSnowEvolution[@o=current()/driftSnowEvolution/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="hoarFrost">
  <tr>
  <xsl:call-template name="src_string"/>
  <td colspan="3">
  <xsl:apply-templates select="phenomDescr"/>
  <xsl:value-of select="concat(' ', $trans/hoarFrost[@o=current()/hoarFrostVal/@v])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="colouredPrecip">
  <tr>
  <xsl:call-template name="src_string"/>
  <td colspan="3">
  <xsl:apply-templates select="phenomDescr"/>
  <xsl:value-of select="concat(' ', $trans/colouredPrecip[@o=current()/colouredPrecipVal/@v])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>
</xsl:stylesheet>
